@@ -30,44 +30,53 @@
 #endif
 
 void checkconvnet(ITG *icutb, ITG *iin,
-		  double *uamt, double *uamf, double *uamp, 
 		  double *cam1t, double *cam1f, double *cam1p,
 		  double *cam2t, double *cam2f, double *cam2p,
 		  double *camt, double *camf, double *camp,
 		  ITG *icntrl, double *dtheta, double *ctrl,
-                  double *uama,double *cam1a,double *cam2a,double *cama,
+                  double *cam1a,double *cam2a,double *cama,
                   double *vamt, double *vamf, double *vamp, double *vama,
-                  double *qa){
+                  double *qa, double *qamt, double *qamf,
+                  double *ramt, double *ramf, double *ramp, ITG *iplausi){
   
   ITG i0,ir,ip,ic,il,ig,ia,idivergence;
   
-  double c1t,c1f,c1p,c1a;
-  double df,dc,db,dd,ran,can,rap,ea,cae,ral;
+  double c2t,c2f,c2p,c2a,c1t,c1f,c1p,qamp=1.,
+         df,dc,db,dd,ran,can,rap,ea,cae,ral;
 
   i0=ctrl[0];ir=ctrl[1];ip=ctrl[2];ic=ctrl[3];il=ctrl[4];ig=ctrl[5];ia=ctrl[7];
-  df=ctrl[10];dc=ctrl[11];db=ctrl[12];dd=ctrl[16];
-  ran=ctrl[18];can=ctrl[19];rap=ctrl[22];
-  ea=ctrl[23];cae=ctrl[24];ral=ctrl[25];
+  df=ctrl[10];dc=ctrl[11];db=ctrl[12];dd=ctrl[16];ran=ctrl[18];can=ctrl[19];
+  rap=ctrl[22];ea=ctrl[23];cae=ctrl[24];ral=ctrl[25];c1t=ctrl[32];c1f=ctrl[33];
+  c1p=ctrl[34];c2t=ctrl[35];c2f=ctrl[36];c2p=ctrl[37];c2a=ctrl[38];
   
   /* temperature */
   
+  if(*iin<=ip){c2t=0.0001*ran;}
+  else{c2t=0.0001*rap;}
+  
   if(*iin<=ip){c1t=0.0001*ran;}
   else{c1t=0.0001*rap;}
   
   /* mass flow */
   
+  if(*iin<=ip){c2f=0.0001*ran;}
+  else{c2f=0.0001*rap;}
+  
   if(*iin<=ip){c1f=0.0001*ran;}
   else{c1f=0.0001*rap;}
   
   /* pressure */
   
+  if(*iin<=ip){c2p=0.0001*ran;}
+  else{c2p=0.0001*rap;}
+  
   if(*iin<=ip){c1p=0.0001*ran;}
   else{c1p=0.0001*rap;}
   
   /* geometry */
   
-  if(*iin<=ip){c1a=0.0001*ran;}
-  else{c1a=0.0001*rap;}
+  if(*iin<=ip){c2a=0.0001*ran;}
+  else{c2a=0.0001*rap;}
   
   if(*cam1t<*cam2t) {*cam2t=*cam1t;}
   if(*cam1f<*cam2f) {*cam2f=*cam1f;}
@@ -75,22 +84,19 @@ void checkconvnet(ITG *icutb, ITG *iin,
   if(*cam1a<*cam2a) {*cam2a=*cam1a;}
   
   /* check for convergence or divergence; 
-     each call of radflowload.c corresponds to a thermomechanical
-     iteration, let's call the iterations within radflowload.c
-     subiterations;
-     the convergence check consists of a comparison of the change in
-     the latest subiteration with
-        - the largest change in the present thermomechanical iteration
-        - the largest value in the present thermomechanical iteration */
+     the convergence check consists of 
+     - a comparison of the correction in
+       the latest network iteration with the change since the 
+       start of the network calculations 
+     - a comparison of the residual in the latest network
+       iteration with mean typical values of the equation terms */
 
-/*  if(((*camt<=c1t**uamt)||(*camt<1.e-8**vamt))&&
-     ((*camf<=c1f**uamf)||(*camf<1.e-8**vamf))&&
-     ((*camp<=c1p**uamp)||(*camp<1.e-8**vamp))&&
-     ((*cama<=c1a**uama)||(*cama<1.e-8**vama))&&*/
-  if(((*camt<=c1t**uamt)||(*camt<c1t**vamt))&&
-     ((*camf<=c1f**uamf)||(*camf<c1f**vamf))&&
-     ((*camp<=c1p**uamp)||(*camp<c1p**vamp))&&
-     ((*cama<=c1a**uama)||(*cama<c1a**vama))&&
+  *ramt=0.;*ramf=0.;*ramp=0.;
+  if((*camt<=c2t**vamt)&&(*ramt<c1t**qamt)&&
+     (*camf<=c2f**vamf)&&(*ramf<c1f**qamf)&&
+     (*camp<=c2p**vamp)&&(*ramp<c1p*qamp)&&
+     (*cama<=c2a**vama)&&
+//     (*cama<=c2a**vama)&&(*iplausi==1)&&
      (*iin>3)){
       
       /* increment convergence reached */
@@ -107,7 +113,7 @@ void checkconvnet(ITG *icutb, ITG *iin,
       /* divergence based on temperatures */
       
       if((*iin>=20*i0)||(fabs(*camt)>1.e20)){
-	  if((*cam1t>=*cam2t)&&(*camt>=*cam2t)&&(*camt>c1t**uamt)){
+	  if((*cam1t>=*cam2t)&&(*camt>=*cam2t)&&(*camt>c2t**vamt)){
 	      idivergence=1;
 	  }
       }
@@ -115,7 +121,7 @@ void checkconvnet(ITG *icutb, ITG *iin,
       /* divergence based on the mass flux */
       
       if((*iin>=20*i0)||(fabs(*camf)>1.e20)){
-	  if((*cam1f>=*cam2f)&&(*camf>=*cam2f)&&(*camf>c1f**uamf)){
+	  if((*cam1f>=*cam2f)&&(*camf>=*cam2f)&&(*camf>c2f**vamf)){
 	      idivergence=1;
 	  }
       }
@@ -123,7 +129,7 @@ void checkconvnet(ITG *icutb, ITG *iin,
       /* divergence based on pressures */
       
       if((*iin>=20*i0)||(fabs(*camp)>1.e20)){
-	  if((*cam1p>=*cam2p)&&(*camp>=*cam2p)&&(*camp>c1p**uamp)){
+	  if((*cam1p>=*cam2p)&&(*camp>=*cam2p)&&(*camp>c2p**vamp)){
 	      idivergence=1;
 	  }
       }
@@ -131,7 +137,7 @@ void checkconvnet(ITG *icutb, ITG *iin,
       /* divergence based on geometry */
       
       if((*iin>=20*i0)||(fabs(*cama)>1.e20)){
-	  if((*cam1a>=*cam2a)&&(*cama>=*cam2a)&&(*cama>c1a**uama)){
+	  if((*cam1a>=*cam2a)&&(*cama>=*cam2a)&&(*cama>c2a**vama)){
 	      idivergence=1;
 	  }
       }
@@ -146,8 +152,8 @@ void checkconvnet(ITG *icutb, ITG *iin,
       
       if(idivergence==1){
 	  *dtheta=*dtheta*df;
-	  printf("\n divergence; the increment size is decreased to %e\n",*dtheta);
-	  printf(" the increment is reattempted\n\n");
+	  printf("\n network divergence; the under-relaxation parameter is decreased to %e\n",*dtheta);
+	  printf(" the network iteration for the increment is reattempted\n\n");
 	  *iin=0;
 	  (*icutb)++;
 	  if(*icutb>ia){
