@@ -17,25 +17,26 @@
 !     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 !
       subroutine designvariabless(inpc,textpart,tieset,tietol,istep,
-     &       istat,n,iline,ipol,inl,ipoinp,inp,ntie,ntie_,ipoinpc)
+     &       istat,n,iline,ipol,inl,ipoinp,inp,ntie,ntie_,ipoinpc,
+     &       set,nset)
 !
 !     reading the input deck: *DESIGNVARIABLES
 !
       implicit none
 !
       character*1 inpc(*)
-      character*81 tieset(3,*)
+      character*81 tieset(3,*),set(*)
       character*132 textpart(16)
 !
       integer istep,istat,n,i,key,ipos,iline,ipol,inl,ipoinp(2,*),
-     &  inp(3,*),ntie,ntie_,ipoinpc(0:*)
+     &  inp(3,*),ntie,ntie_,ipoinpc(0:*),nset,itype
 !
       real*8 tietol(3,*)
 !
 !     Check of correct position in Inputdeck
 !
       if(istep.gt.0) then
-         write(*,*) '*ERROR in designvariabless: *DESIGNVARIABLES'
+         write(*,*) '*ERROR reading *DESIGN VARIABLES: *DESIGNVARIABLES'
          write(*,*) ' should be placed before all step definitions'
          call exit(201)
       endif
@@ -44,24 +45,26 @@
 !
       ntie=ntie+1
       if(ntie.gt.ntie_) then
-         write(*,*) '*ERROR in designvaribaless: increase ntie_'
+         write(*,*) '*ERROR reading *DESIGN VARIABLES: increase ntie_'
          call exit(201)
       endif
 !
 !     Read in *DESIGNVARIABLES
 !
+      itype=0
       do i=2,n
-         if(textpart(i)(1:5).eq.'NAME=') then
+         if(textpart(i)(1:5).eq.'TYPE=') then
             read(textpart(i)(6:85),'(a80)',iostat=istat) 
      &           tieset(1,ntie)(1:80)
             if(istat.gt.0) call inputerror(inpc,ipoinpc,iline,
      &           "*DESIGNVARIABLE%")
+            itype=1
          endif
        enddo  
 !
-      if(tieset(1,ntie)(1:1).eq.' ') then
+      if(itype.eq.0) then
          write(*,*) 
-     &'*ERROR in designvaribaless: designvariables name is lacking'
+     &'*ERROR reading *DESIGN VARIABLES: type is lacking'
          call inputerror(inpc,ipoinpc,iline,
      &"*DESIGNVARIABLE%")
          call exit(201)
@@ -71,18 +74,35 @@
 !      
       tieset(1,ntie)(81:81)='D' 
 !
-      call getnewline(inpc,textpart,istat,n,key,iline,ipol,inl,
+      if(tieset(1,ntie)(1:10).eq.'COORDINATE') then
+         call getnewline(inpc,textpart,istat,n,key,iline,ipol,inl,
      &     ipoinp,inp,ipoinpc)
-      if((istat.lt.0).or.(key.eq.1)) then
-         write(*,*)
-     &'*ERROR in designvaribaless: definition of the designvariables'
-         write(*,*) '      is not complete.'
-         call exit(201)
+         if((istat.lt.0).or.(key.eq.1)) then
+            write(*,*)
+     &'*ERROR reading *DESIGN VARIABLES: definition'
+            write(*,*) '      is not complete.'
+            call exit(201)
+         endif
+!
+!        Read the name of the design variable node set
+!
+         tieset(2,ntie)(1:81)=textpart(1)(1:81)
+         ipos=index(tieset(2,ntie),' ')
+         tieset(2,ntie)(ipos:ipos)='N'
+!
+!        Check existence of the node set
+!
+         do i=1,nset
+            if(set(i).eq.tieset(2,ntie)) exit
+         enddo
+         if(i.gt.nset) then
+            write(*,*) '*ERROR reading *DESIGN VARIABLES'
+            write(*,*) 'node set ',tieset(2,ntie)(1:ipos-1),
+     &           'does not exist. Card image:'
+            call inputerror(inpc,ipoinpc,iline,
+     &"*DESIGN VARIABLES%")
+         endif
       endif
-!
-!     Read the name of the designvariable node set
-!
-      tieset(2,ntie)(1:81)=textpart(1)(1:81)
 !
       call getnewline(inpc,textpart,istat,n,key,iline,ipol,inl,
      &     ipoinp,inp,ipoinpc)
