@@ -41,10 +41,10 @@
       character*8 lakonl
       character*80 matname(*),amat
 !
-      integer konl(26),ifaceq(9,6),nelem,nmethod,iactive(3),
+      integer konl(26),ifaceq(8,6),nelem,nmethod,iactive(3),
      &  ithermal,idist,i,j,k,i1,m,one,ii,jj,id,ipointer,ig,kk,mi(*),
      &  ielmat(mi(3),*),ntmat_,nope,nopes,imat,mint2d,mint3d,
-     &  ifacet(7,4),nopev,ifacew(8,5),ipointeri,ipointerj,iflag,
+     &  ifacet(6,4),nopev,ifacew(8,5),ipointeri,ipointerj,iflag,
      &  nelcon(2,*),ncmat_,nalcon(2,*),iel,ii1,ilength,istart,iset,
      &  isurf,jj1,istartset(*),iendset(*),ialset(*),three,nfaces
 !
@@ -57,16 +57,16 @@
 !
       include "gauss.f"
 !
-      data ifaceq /4,3,2,1,11,10,9,12,21,
-     &            5,6,7,8,13,14,15,16,22,
-     &            1,2,6,5,9,18,13,17,23,
-     &            2,3,7,6,10,19,14,18,24,
-     &            3,4,8,7,11,20,15,19,25,
-     &            4,1,5,8,12,17,16,20,26/
-      data ifacet /1,3,2,7,6,5,11,
-     &             1,2,4,5,9,8,12,
-     &             2,3,4,6,10,9,13,
-     &             1,4,3,8,10,7,14/
+      data ifaceq /4,3,2,1,11,10,9,12,
+     &            5,6,7,8,13,14,15,16,
+     &            1,2,6,5,9,18,13,17,
+     &            2,3,7,6,10,19,14,18,
+     &            3,4,8,7,11,20,15,19,
+     &            4,1,5,8,12,17,16,20/
+      data ifacet /1,3,2,7,6,5,
+     &             1,2,4,5,9,8,
+     &             2,3,4,6,10,9,
+     &             1,4,3,8,10,7/
       data ifacew /1,3,2,9,8,7,0,0,
      &             4,5,6,10,11,12,0,0,
      &             1,2,5,4,7,14,10,13,
