@@ -16,19 +16,20 @@
 !     along with this program; if not, write to the Free Software
 !     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 !
-      subroutine extrapolate_gradtel(nface,ielfa,xrlfa,gradtel,gradtfa)
+      subroutine extrapolate_gradtel(nface,ielfa,xrlfa,gradtel,gradtfa,
+     &           icyclic,c,ifatie)
 !
 !     inter/extrapolation of p element values to the faces
 !
       implicit none
 !
-      integer nface,ielfa(4,*),i,iel1,iel2,l
+      integer nface,ielfa(4,*),i,iel1,iel2,l,icyclic,ifatie(*)
 !
-      real*8 xrlfa(3,*),gradtel(3,*),gradtfa(3,*),xl1
+      real*8 xrlfa(3,*),gradtel(3,*),gradtfa(3,*),xl1,xl2,c(3,3)
 !     
 c$omp parallel default(none)
-c$omp& shared(nface,ielfa,xrlfa,gradtfa,gradtel)
-c$omp& private(i,iel1,xl1,iel2,l)
+c$omp& shared(nface,ielfa,xrlfa,gradtfa,gradtel,icyclic,c,ifatie)
+c$omp& private(i,iel1,xl1,iel2,l,xl2)
 c$omp do
       do i=1,nface
          iel1=ielfa(1,i)
@@ -38,10 +39,27 @@ c$omp do
 !
 !           face in between two elements
 !
-            do l=1,3
-               gradtfa(l,i)=xl1*gradtel(l,iel1)+
-     &              xrlfa(2,i)*gradtel(l,iel2)
-            enddo
+            xl2=xrlfa(2,i)
+            if((icyclic.eq.0).or.(ifatie(i).eq.0)) then
+               do l=1,3
+                  gradtfa(l,i)=xl1*gradtel(l,iel1)+
+     &                 xl2*gradtel(l,iel2)
+               enddo
+            elseif(ifatie(i).gt.0) then
+               do l=1,3
+                  gradtfa(l,i)=xl1*gradtel(l,iel1)+xl2*
+     &                  (gradtel(1,iel2)*c(l,1)+
+     &                   gradtel(2,iel2)*c(l,2)+
+     &                   gradtel(3,iel2)*c(l,3))
+               enddo
+            else
+               do l=1,3
+                  gradtfa(l,i)=xl1*gradtel(l,iel1)+xl2*
+     &                  (gradtel(1,iel2)*c(1,l)+
+     &                   gradtel(2,iel2)*c(2,l)+
+     &                   gradtel(3,iel2)*c(3,l))
+               enddo
+            endif
          elseif(ielfa(3,i).gt.0) then
 !     
 !     boundary face; linear extrapolation
