@@ -22,11 +22,6 @@
 !
 !     extrapolates contact values at the integration points to the 
 !     nodes (for face-to-face penalty contact)
-!
-!     the C3D20RB element has 50 integration points, however, the
-!     first 8 integration points coincide with those of a C3D20R
-!     element. In this routine and in errorestimator.f the C3D20RB
-!     element is treated as an ordinary C3D20R element
 !
       implicit none
 !
@@ -39,7 +34,7 @@
      &  nonei20(3,12),nfield,nonei10(3,6),nk,i,j,k,l,ndim,
      &  nonei15(3,9),m,iflag,jj,indexc,islavsurf(2,*),ll,
      &  indexcj,ifacew1(4,5),islavnode(*),nslavnode(*),ntie,
-     &  nlayer,nopeexp,ifacew2(8,5),ifaceq(9,6),ifacet(7,4),
+     &  nlayer,nopeexp,ifacew2(8,5),ifaceq(8,6),ifacet(6,4),
      &  nopespring,ifaces,nopespringj,ifacej,jfaces,n,nelems,
      &  idgn,idgnr,idglda,idgip(4),idgldb,idginfo,igauss,islavact(*),
      &  konl(26),node,nopes,ielprop(*),ielmat(mi(3),*),ne0,
@@ -64,19 +59,19 @@
 !
 !     nodes per face for hex elements
 !
-      data ifaceq /4,3,2,1,11,10,9,12,21,
-     &            5,6,7,8,13,14,15,16,22,
-     &            1,2,6,5,9,18,13,17,23,
-     &            2,3,7,6,10,19,14,18,24,
-     &            3,4,8,7,11,20,15,19,25,
-     &            4,1,5,8,12,17,16,20,26/
+      data ifaceq /4,3,2,1,11,10,9,12,
+     &            5,6,7,8,13,14,15,16,
+     &            1,2,6,5,9,18,13,17,
+     &            2,3,7,6,10,19,14,18,
+     &            3,4,8,7,11,20,15,19,
+     &            4,1,5,8,12,17,16,20/
 !
 !     nodes per face for tet elements
 !
-      data ifacet /1,3,2,7,6,5,11,
-     &             1,2,4,5,9,8,12,
-     &             2,3,4,6,10,9,13,
-     &             1,4,3,8,10,7,14/
+      data ifacet /1,3,2,7,6,5,
+     &             1,2,4,5,9,8,
+     &             2,3,4,6,10,9,
+     &             1,4,3,8,10,7/
 !
 !     nodes per face for linear wedge elements
 !
@@ -95,140 +90,6 @@
      &             3,1,4,6,9,13,12,15/
 !
       data iflag /2/
-c!     
-c!     local coordinates of the element nodes
-c!
-c      data xquad /-1.d0,-1.d0,
-c     &             1.d0,-1.d0,
-c     &             1.d0,1.d0,
-c     &            -1.d0,1.d0,
-c     &             0.d0,-1.d0,
-c     &             1.d0,0.d0,
-c     &             0.d0,1.d0,
-c     &            -1.d0,0.d0,
-c     &             0.d0,0.d0/
-c!
-c      data xtri /0.d0,0.d0,
-c     &           1.d0,0.d0,
-c     &           0.d0,1.d0,
-c     &           .5d0,0.d0,
-c     &           .5d0,.5d0,
-c     &           0.d0,.5d0,
-c     &           0.333333333333333d0,0.333333333333333d0/
-c!
-c      data a2 /  1.1455,-0.1455,1.1455,-0.1455,1.1455,-0.1455,
-c     &           -0.1455,1.1455,-0.1455,1.1455,-0.1455,1.1455/
-c      data a4 /  1.92705, -0.30902, -0.30902, -0.30902,
-c     &          -0.30902,  1.92705, -0.30902, -0.30902,
-c     &          -0.30902, -0.30902,  1.92705, -0.30902,
-c     &          -0.30902, -0.30902, -0.30902,  1.92705/
-c      data a9 / 1.63138,-0.32628,-0.32628,-0.52027, 0.10405, 0.10405,
-c     &         -0.32628, 1.63138,-0.32628, 0.10405,-0.52027, 0.10405,
-c     &         -0.32628,-0.32628, 1.63138, 0.10405, 0.10405,-0.52027,
-c     &          0.55556,-0.11111,-0.11111, 0.55556,-0.11111,-0.11111,
-c     &         -0.11111, 0.55556,-0.11111,-0.11111, 0.55556,-0.11111,
-c     &         -0.11111,-0.11111, 0.55556,-0.11111,-0.11111, 0.55556,
-c     &         -0.52027, 0.10405, 0.10405, 1.63138,-0.32628,-0.32628,
-c     &          0.10405,-0.52027, 0.10405,-0.32628, 1.63138,-0.32628,
-c     &          0.10405, 0.10405,-0.52027,-0.32628,-0.32628, 1.63138/
-c!
-c!     extrapolation from a 2x2x2=8 integration point scheme in a hex to
-c!     the vertex nodes
-c!    
-c      data a8 /2.549,-.683,.183,-.683,-.683,.183,
-c     &        -.04904,.183,-.683,2.549,-.683,.183,
-c     &        .183,-.683,.183,-.04904,-.683,.183,
-c     &        -.683,2.549,.183,-.04904,.183,-.683,
-c     &        .183,-.683,2.549,-.683,-.04904,.183,
-c     &        -.683,.183,-.683,.183,-.04904,.183,
-c     &        2.549,-.683,.183,-.683,.183,-.683,
-c     &        .183,-.04904,-.683,2.549,-.683,.183,
-c     &        .183,-.04904,.183,-.683,-.683,.183,
-c     &        -.683,2.549,-.04904,.183,-.683,.183,
-c     &        .183,-.683,2.549,-.683/  
-c!
-c!     extrapolation from a 3x3x3=27 integration point scheme in a hex to
-c!     the all nodes in a 20-node element
-c!    
-c      data a27 /
-c     &  2.37499,-0.12559,-0.16145,-0.12559,-0.12559,-0.16145, 0.11575,
-c     & -0.16145, 0.32628, 0.11111, 0.11111, 0.32628, 0.11111,-0.10405,
-c     & -0.10405, 0.11111, 0.32628, 0.11111,-0.10405, 0.11111,-0.31246,
-c     & -0.31246, 0.31481, 0.31481, 0.31481, 0.31481,-0.16902,-0.16902,
-c     &  1.28439,-0.27072,-0.19444,-0.27072,-0.19444, 0.15961,-0.00661,
-c     &  0.15961,-0.27072,-0.27072, 0.15961, 0.15961,-0.12559, 2.37499,
-c     & -0.12559,-0.16145,-0.16145,-0.12559,-0.16145, 0.11575, 0.32628,
-c     &  0.32628, 0.11111, 0.11111, 0.11111, 0.11111,-0.10405,-0.10405,
-c     &  0.11111, 0.32628, 0.11111,-0.10405,-0.31246, 0.31481, 0.31481,
-c     & -0.31246, 0.31481,-0.16902,-0.16902, 0.31481,-0.27072,-0.19444,
-c     & -0.27072, 1.28439, 0.15961,-0.00661, 0.15961,-0.19444,-0.27072,
-c     &  0.15961, 0.15961,-0.27072,-0.48824,-0.48824,-0.48824,-0.48824,
-c     &  0.22898, 0.22898, 0.22898, 0.22898, 0.05556, 0.05556, 0.05556,
-c     &  0.05556, 0.05556, 0.05556, 0.05556, 0.05556,-0.22222,-0.22222,
-c     & -0.22222,-0.22222, 0.31481,-0.31246,-0.31246, 0.31481,-0.16902,
-c     &  0.31481, 0.31481,-0.16902,-0.27072, 1.28439,-0.27072,-0.19444,
-c     &  0.15961,-0.19444, 0.15961,-0.00661, 0.15961,-0.27072,-0.27072,
-c     &  0.15961,-0.12559,-0.16145,-0.12559, 2.37499,-0.16145, 0.11575,
-c     & -0.16145,-0.12559, 0.11111, 0.11111, 0.32628, 0.32628,-0.10405,
-c     & -0.10405, 0.11111, 0.11111, 0.11111,-0.10405, 0.11111, 0.32628,
-c     &  0.31481, 0.31481,-0.31246,-0.31246,-0.16902,-0.16902, 0.31481,
-c     &  0.31481,-0.19444,-0.27072, 1.28439,-0.27072,-0.00661, 0.15961,
-c     & -0.19444, 0.15961, 0.15961, 0.15961,-0.27072,-0.27072,-0.16145,
-c     & -0.12559, 2.37499,-0.12559, 0.11575,-0.16145,-0.12559,-0.16145,
-c     &  0.11111, 0.32628, 0.32628, 0.11111,-0.10405, 0.11111, 0.11111,
-c     & -0.10405,-0.10405, 0.11111, 0.32628, 0.11111,-0.31246, 0.31481,
-c     & -0.16902, 0.31481,-0.31246, 0.31481,-0.16902, 0.31481,-0.27072,
-c     &  0.15961, 0.15961,-0.27072,-0.27072, 0.15961, 0.15961,-0.27072,
-c     &  1.28439,-0.19444,-0.00661,-0.19444,-0.48824,-0.48824, 0.22898,
-c     &  0.22898,-0.48824,-0.48824, 0.22898, 0.22898, 0.05556,-0.22222,
-c     &  0.05556,-0.22222, 0.05556,-0.22222, 0.05556,-0.22222, 0.05556,
-c     &  0.05556, 0.05556, 0.05556, 0.31481,-0.31246, 0.31481,-0.16902,
-c     &  0.31481,-0.31246, 0.31481,-0.16902,-0.27072,-0.27072, 0.15961,
-c     &  0.15961,-0.27072,-0.27072, 0.15961, 0.15961,-0.19444, 1.28439,
-c     & -0.19444,-0.00661,-0.48824, 0.22898, 0.22898,-0.48824,-0.48824,
-c     &  0.22898, 0.22898,-0.48824,-0.22222, 0.05556,-0.22222, 0.05556,
-c     & -0.22222, 0.05556,-0.22222, 0.05556, 0.05556, 0.05556, 0.05556,
-c     &  0.05556,-0.29630,-0.29630,-0.29630,-0.29630,-0.29630,-0.29630,
-c     & -0.29630,-0.29630,-0.11111,-0.11111,-0.11111,-0.11111,-0.11111,
-c     & -0.11111,-0.11111,-0.11111,-0.11111,-0.11111,-0.11111,-0.11111,
-c     &  0.22898,-0.48824,-0.48824, 0.22898, 0.22898,-0.48824,-0.48824,
-c     &  0.22898,-0.22222, 0.05556,-0.22222, 0.05556,-0.22222, 0.05556,
-c     & -0.22222, 0.05556, 0.05556, 0.05556, 0.05556, 0.05556, 0.31481,
-c     & -0.16902, 0.31481,-0.31246, 0.31481,-0.16902, 0.31481,-0.31246,
-c     &  0.15961, 0.15961,-0.27072,-0.27072, 0.15961, 0.15961,-0.27072,
-c     & -0.27072,-0.19444,-0.00661,-0.19444, 1.28439, 0.22898, 0.22898,
-c     & -0.48824,-0.48824, 0.22898, 0.22898,-0.48824,-0.48824, 0.05556,
-c     & -0.22222, 0.05556,-0.22222, 0.05556,-0.22222, 0.05556,-0.22222,
-c     &  0.05556, 0.05556, 0.05556, 0.05556,-0.16902, 0.31481,-0.31246,
-c     &  0.31481,-0.16902, 0.31481,-0.31246, 0.31481, 0.15961,-0.27072,
-c     & -0.27072, 0.15961, 0.15961,-0.27072,-0.27072, 0.15961,-0.00661,
-c     & -0.19444, 1.28439,-0.19444,-0.12559,-0.16145, 0.11575,-0.16145,
-c     &  2.37499,-0.12559,-0.16145,-0.12559, 0.11111,-0.10405,-0.10405,
-c     &  0.11111, 0.32628, 0.11111, 0.11111, 0.32628, 0.32628, 0.11111,
-c     & -0.10405, 0.11111, 0.31481, 0.31481,-0.16902,-0.16902,-0.31246,
-c     & -0.31246, 0.31481, 0.31481,-0.19444, 0.15961,-0.00661, 0.15961,
-c     &  1.28439,-0.27072,-0.19444,-0.27072,-0.27072,-0.27072, 0.15961,
-c     &  0.15961,-0.16145,-0.12559,-0.16145, 0.11575,-0.12559, 2.37499,
-c     & -0.12559,-0.16145, 0.11111, 0.11111,-0.10405,-0.10405, 0.32628,
-c     &  0.32628, 0.11111, 0.11111, 0.11111, 0.32628, 0.11111,-0.10405,
-c     &  0.31481,-0.16902,-0.16902, 0.31481,-0.31246, 0.31481, 0.31481,
-c     & -0.31246, 0.15961,-0.00661, 0.15961,-0.19444,-0.27072,-0.19444,
-c     & -0.27072, 1.28439,-0.27072, 0.15961, 0.15961,-0.27072, 0.22898,
-c     &  0.22898, 0.22898, 0.22898,-0.48824,-0.48824,-0.48824,-0.48824,
-c     &  0.05556, 0.05556, 0.05556, 0.05556, 0.05556, 0.05556, 0.05556,
-c     &  0.05556,-0.22222,-0.22222,-0.22222,-0.22222,-0.16902, 0.31481,
-c     &  0.31481,-0.16902, 0.31481,-0.31246,-0.31246, 0.31481, 0.15961,
-c     & -0.19444, 0.15961,-0.00661,-0.27072, 1.28439,-0.27072,-0.19444,
-c     &  0.15961,-0.27072,-0.27072, 0.15961,-0.16145, 0.11575,-0.16145,
-c     & -0.12559,-0.12559,-0.16145,-0.12559, 2.37499,-0.10405,-0.10405,
-c     &  0.11111, 0.11111, 0.11111, 0.11111, 0.32628, 0.32628, 0.11111,
-c     & -0.10405, 0.11111, 0.32628,-0.16902,-0.16902, 0.31481, 0.31481,
-c     &  0.31481, 0.31481,-0.31246,-0.31246,-0.00661, 0.15961,-0.19444,
-c     &  0.15961,-0.19444,-0.27072, 1.28439,-0.27072, 0.15961, 0.15961,
-c     & -0.27072,-0.27072, 0.11575,-0.16145,-0.12559,-0.16145,-0.16145,
-c     & -0.12559, 2.37499,-0.12559,-0.10405, 0.11111, 0.11111,-0.10405,
-c     &  0.11111, 0.32628, 0.32628, 0.11111,-0.10405, 0.11111, 0.32628,
-c     &  0.11111/
 !
       if(nfield.eq.0) return
 !
@@ -278,7 +139,7 @@ c     &  0.11111/
             nope=20
          elseif(lakonl(4:4).eq.'8') then
             nope=8
-         elseif((lakonl(4:5).eq.'10').or.(lakonl(4:5).eq.'14')) then
+         elseif(lakonl(4:5).eq.'10') then
             nope=10
          elseif(lakonl(4:4).eq.'4') then
             nope=4
@@ -545,7 +406,7 @@ c     &  0.11111/
 !     determining the field values in the midside nodes of the
 !     slave face
 !     
-         if((lakonl(4:5).eq.'20').or.(lakonl(4:6).eq.'26R')) then
+         if(lakonl(4:5).eq.'20') then
             if(lakonl(7:8).ne.'LC') then
                do j=5,8
                   do k=1,nfield
@@ -565,7 +426,7 @@ c     &  0.11111/
                   enddo
                enddo
             endif
-         elseif((lakonl(4:5).eq.'10').or.(lakonl(4:5).eq.'14')) then
+         elseif(lakonl(4:5).eq.'10') then
             do j=4,6
                do k=1,nfield
                   field(k,ifacet(j,jfaces))=
