@@ -52,9 +52,9 @@
 !
       real*8 co(3,*),xboun(*),coefmpc(*),xforc(*),xload(2,*),p1(3),
      &  p2(3),ad(*),au(*),bodyf(3),voldl(0:mi(2),26),clearini(3,9,*),
-     &  t0(*),t1(*),prestr(6,mi(1),*),vold(0:mi(2),*),s(100,100),
-     &  ff(100),
-     &  sti(6,mi(1),*),sm(100,100),stx(6,mi(1),*),adb(*),aub(*),
+     &  t0(*),t1(*),prestr(6,mi(1),*),vold(0:mi(2),*),s(60,60),
+     &  ff(60),
+     &  sti(6,mi(1),*),sm(60,60),stx(6,mi(1),*),adb(*),aub(*),
      &  elcon(0:ncmat_,ntmat_,*),rhcon(0:1,ntmat_,*),elas(21),
      &  alcon(0:6,ntmat_,*),alzero(*),orab(7,*),xbody(7,*),cgr(4,*),
      &  plicon(0:2*npmat_,ntmat_,*),plkcon(0:2*npmat_,ntmat_,*),
@@ -182,28 +182,32 @@ c      enddo
 !     
 !     check whether one of the DOF belongs to a SPC or MPC
 !     
-                  if((jdof1.ne.0).and.(jdof2.ne.0)) then
+                  if((jdof1.gt.0).and.(jdof2.gt.0)) then
                      call add_sm_st(au,ad,jq,irow,jdof1,jdof2,
      &                    s(jj,ll),jj,ll)
-                  elseif((jdof1.ne.0).or.(jdof2.ne.0)) then
+                  elseif((jdof1.gt.0).or.(jdof2.gt.0)) then
 !     
 !     idof1: genuine DOF
 !     idof2: nominal DOF of the SPC/MPC
 !     
-                     if(jdof1.eq.0) then
+                     if(jdof1.le.0) then
                         idof1=jdof2
-                        idof2=(node1-1)*8+k
+c                        idof2=(node1-1)*8+k
+                        idof2=jdof1
                      else
                         idof1=jdof1
-                        idof2=(node2-1)*8+m
+c                        idof2=(node2-1)*8+m
+                        idof2=jdof2
                      endif
                      if(nmpc.gt.0) then
-                        call nident(ikmpc,idof2,nmpc,id)
-                        if((id.gt.0).and.(ikmpc(id).eq.idof2)) then
+c                        call nident(ikmpc,idof2,nmpc,id)
+c                        if((id.gt.0).and.(ikmpc(id).eq.idof2)) then
+                        if(idof2.ne.2*(idof2/2)) then
 !     
 !     regular DOF / MPC
 !     
-                           id=ilmpc(id)
+c                           id=ilmpc(id)
+                           id=(-idof2+1)/2
                            ist=ipompc(id)
                            index=nodempc(3,ist)
                            if(index.eq.0) cycle
@@ -213,7 +217,7 @@ c      enddo
                               value=-coefmpc(index)*s(jj,ll)/
      &                                        coefmpc(ist)
                               if(idof1.eq.idof2) value=2.d0*value
-                              if(idof2.ne.0) then
+                              if(idof2.gt.0) then
                                  call add_sm_st(au,ad,jq,irow,idof1,
      &                                idof2,value,i0,i0)
                               endif
@@ -224,19 +228,25 @@ c      enddo
                         endif
                      endif
                   else
-                     idof1=(node1-1)*8+k
-                     idof2=(node2-1)*8+m
+c                     idof1=(node1-1)*8+k
+c                     idof2=(node2-1)*8+m
+                     idof1=jdof1
+                     idof2=jdof2
                      mpc1=0
                      mpc2=0
                      if(nmpc.gt.0) then
-                        call nident(ikmpc,idof1,nmpc,id1)
-                        if((id1.gt.0).and.(ikmpc(id1).eq.idof1)) mpc1=1
-                        call nident(ikmpc,idof2,nmpc,id2)
-                        if((id2.gt.0).and.(ikmpc(id2).eq.idof2)) mpc2=1
+c                        call nident(ikmpc,idof1,nmpc,id1)
+c                        if((id1.gt.0).and.(ikmpc(id1).eq.idof1)) mpc1=1
+c                        call nident(ikmpc,idof2,nmpc,id2)
+c                        if((id2.gt.0).and.(ikmpc(id2).eq.idof2)) mpc2=1
+                        if(idof1.ne.2*(idof1/2)) mpc1=1
+                        if(idof2.ne.2*(idof2/2)) mpc2=1
                      endif
                      if((mpc1.eq.1).and.(mpc2.eq.1)) then
-                        id1=ilmpc(id1)
-                        id2=ilmpc(id2)
+c                        id1=ilmpc(id1)
+c                        id2=ilmpc(id2)
+                        id1=(-idof1+1)/2
+                        id2=(-idof2+1)/2
                         if(id1.eq.id2) then
 !     
 !     MPC id1 / MPC id1
@@ -253,7 +263,7 @@ c      enddo
      &                                nodempc(1,index2))
                                  value=coefmpc(index1)*coefmpc(index2)*
      &                                s(jj,ll)/coefmpc(ist)/coefmpc(ist)
-                                 if((idof1.ne.0).and.(idof2.ne.0)) then
+                                 if((idof1.gt.0).and.(idof2.gt.0)) then
                                     call add_sm_st(au,ad,jq,irow,
      &                                   idof1,idof2,value,i0,i0)
                                  endif
@@ -291,7 +301,7 @@ c      enddo
      &                                s(jj,ll)/coefmpc(ist1)/
      &                                         coefmpc(ist2)
                                  if(idof1.eq.idof2) value=2.d0*value
-                                 if((idof1.ne.0).and.(idof2.ne.0)) then
+                                 if((idof1.gt.0).and.(idof2.gt.0)) then
                                     call add_sm_st(au,ad,jq,irow,
      &                                   idof1,idof2,value,i0,i0)
                                  endif
@@ -331,24 +341,27 @@ c      enddo
 !     
 !     check whether one of the DOF belongs to a SPC or MPC
 !     
-              if((jdof1.ne.0).and.(jdof2.ne.0)) then
+              if((jdof1.gt.0).and.(jdof2.gt.0)) then
                  call add_sm_st_as(au,ad,jq,irow,jdof1,jdof2,
      &                s(jj,ll),jj,ll,nzs)
-              elseif((jdof1.ne.0).or.(jdof2.ne.0)) then
+              elseif((jdof1.gt.0).or.(jdof2.gt.0)) then
 !     
 !     idof1: genuine DOF
 !     idof2: nominal DOF of the SPC/MPC
 !     
-                 if(jdof1.eq.0) then
-                    idof1=(node1-1)*8+k
+                 if(jdof1.le.0) then
+c                    idof1=(node1-1)*8+k
+                    idof1=jdof1
                     idof2=jdof2
                     if(nmpc.gt.0) then
-                       call nident(ikmpc,idof1,nmpc,id)
-                       if((id.gt.0).and.(ikmpc(id).eq.idof1)) then
+c                       call nident(ikmpc,idof1,nmpc,id)
+c                       if((id.gt.0).and.(ikmpc(id).eq.idof1)) then
+                       if(idof1.ne.2*(idof1/2)) then
 !     
 !     regular DOF / MPC
 !     
-                          id=ilmpc(id)
+c                          id=ilmpc(id)
+                          id=(-idof1+1)/2
                           ist=ipompc(id)
                           index=nodempc(3,ist)
                           if(index.eq.0) cycle
@@ -356,7 +369,7 @@ c      enddo
                              idof1=nactdof(nodempc(2,index),
      &                              nodempc(1,index))
                              value=-coefmpc(index)*s(jj,ll)/coefmpc(ist)
-                             if(idof1.ne.0) then
+                             if(idof1.gt.0) then
                                 call add_sm_st_as(au,ad,jq,irow,idof1,
      &                               idof2,value,i0,i0,nzs)
                              endif
@@ -368,14 +381,17 @@ c      enddo
                     endif
                  else
                     idof1=jdof1
-                    idof2=(node2-1)*8+m
+c                    idof2=(node2-1)*8+m
+                    idof2=jdof2
                     if(nmpc.gt.0) then
-                       call nident(ikmpc,idof2,nmpc,id)
-                       if((id.gt.0).and.(ikmpc(id).eq.idof2)) then
+c                       call nident(ikmpc,idof2,nmpc,id)
+c                       if((id.gt.0).and.(ikmpc(id).eq.idof2)) then
+                       if(idof2.ne.2*(idof2/2)) then
 !     
 !     regular DOF / MPC
 !     
-                          id=ilmpc(id)
+c                          id=ilmpc(id)
+                          id=(-idof2+1)/2
                           ist=ipompc(id)
                           index=nodempc(3,ist)
                           if(index.eq.0) cycle
@@ -383,7 +399,7 @@ c      enddo
                              idof2=nactdof(nodempc(2,index),
      &                             nodempc(1,index))
                              value=-coefmpc(index)*s(jj,ll)/coefmpc(ist)
-                             if(idof2.ne.0) then
+                             if(idof2.gt.0) then
                                 call add_sm_st_as(au,ad,jq,irow,idof1,
      &                               idof2,value,i0,i0,nzs)
                              endif
@@ -395,19 +411,25 @@ c      enddo
                     endif
                  endif
               else
-                 idof1=(node1-1)*8+k
-                 idof2=(node2-1)*8+m
+c                 idof1=(node1-1)*8+k
+c                 idof2=(node2-1)*8+m
+                 idof1=jdof1
+                 idof2=jdof2
                  mpc1=0
                  mpc2=0
                  if(nmpc.gt.0) then
-                    call nident(ikmpc,idof1,nmpc,id1)
-                    if((id1.gt.0).and.(ikmpc(id1).eq.idof1)) mpc1=1
-                    call nident(ikmpc,idof2,nmpc,id2)
-                    if((id2.gt.0).and.(ikmpc(id2).eq.idof2)) mpc2=1
+c                    call nident(ikmpc,idof1,nmpc,id1)
+c                    if((id1.gt.0).and.(ikmpc(id1).eq.idof1)) mpc1=1
+c                    call nident(ikmpc,idof2,nmpc,id2)
+c                    if((id2.gt.0).and.(ikmpc(id2).eq.idof2)) mpc2=1
+                    if(idof1.ne.2*(idof1/2)) mpc1=1
+                    if(idof2.ne.2*(idof2/2)) mpc2=1
                  endif
                  if((mpc1.eq.1).and.(mpc2.eq.1)) then
-                    id1=ilmpc(id1)
-                    id2=ilmpc(id2)
+c                    id1=ilmpc(id1)
+c                    id2=ilmpc(id2)
+                    id1=(-idof1+1)/2
+                    id2=(-idof2+1)/2
                     if(id1.eq.id2) then
 !     
 !     MPC id1 / MPC id1
@@ -436,7 +458,7 @@ c                             value=coefmpc(index1)*coefmpc(index2)*
 c     &                            s(jj,ll)/coefmpc(ist)/coefmpc(ist)
                              value=coefmpc(index1)*coefmpc(index2)*
      &                            s(jj,ll)/coefmpc(ist1)/coefmpc(ist2)
-                             if((idof1.ne.0).and.(idof2.ne.0)) then
+                             if((idof1.gt.0).and.(idof2.gt.0)) then
                                 call add_sm_st_as(au,ad,jq,irow,
      &                               idof1,idof2,value,i0,i0,nzs)
                              endif
@@ -472,7 +494,7 @@ c     &                            s(jj,ll)/coefmpc(ist)/coefmpc(ist)
      &                            nodempc(1,index2))
                              value=coefmpc(index1)*coefmpc(index2)*
      &                            s(jj,ll)/coefmpc(ist1)/coefmpc(ist2)
-                             if((idof1.ne.0).and.(idof2.ne.0)) then
+                             if((idof1.gt.0).and.(idof2.gt.0)) then
                                 call add_sm_st_as(au,ad,jq,irow,
      &                               idof1,idof2,value,i0,i0,nzs)
                              endif
