@@ -31,7 +31,8 @@
      &  coriolis,ibody,xloadold,reltime,veold,springarea,nstate_,
      &  xstateini,xstate,thicke,integerglob,doubleglob,
      &  tieset,istartset,iendset,ialset,ntie,nasym,iactive,h0,
-     &  pslavsurf,pmastsurf,mortar,clearini,ielprop,prop)
+     &  pslavsurf,pmastsurf,mortar,clearini,ielprop,prop,
+     &  iponoel,inoel)
 !
 !     filling the stiffness matrix in spare matrix format (sm)
 !
@@ -62,7 +63,7 @@
      &  mpc1,mpc2,index1,index2,jdof,node1,node2,kflag,icalccg,
      &  ntmat_,indexe,nope,norien,iexpl,i0,ncmat_,istep,iinc,mortar,
      &  nplicon(0:ntmat_,*),nplkcon(0:ntmat_,*),npmat_,iactive(3),
-     &  ielprop(*)
+     &  ielprop(*),iponoel(*),inoel(2,*)
 !
       real*8 co(3,*),xboun(*),coefmpc(*),xforc(*),xload(2,*),p1(3),
      &  p2(3),ad(*),au(*),bodyf(3),fext(*),xloadold(2,*),reltime,
@@ -74,7 +75,7 @@
      &  shcon(0:3,ntmat_,*),alzero(*),orab(7,*),xbody(7,*),cgr(4,*),
      &  plicon(0:2*npmat_,ntmat_,*),plkcon(0:2*npmat_,ntmat_,*),
      &  xstiff(27,mi(1),*),veold(0:mi(2),*),om,valu2,value,dtime,ttime,
-     &  time,thicke(mi(3),*),doubleglob(*),h0(3,*),
+     &  time,thicke(mi(3),*),doubleglob(*),h0(3,*),st(60,60),smt(60,60),
      &  pslavsurf(3,*),pmastsurf(6,*),clearini(3,9,*),prop(*)
 !
       kflag=2
@@ -191,7 +192,7 @@
 !
 !           check whether one of the DOF belongs to a SPC or MPC
 !
-            if((jdof1.ne.0).and.(jdof2.ne.0)) then
+            if((jdof1.gt.0).and.(jdof2.gt.0)) then
                if(stiffonly(1)) then
                   call add_sm_st(au,ad,jq,irow,jdof1,jdof2,
      &                 s(jj,ll),jj,ll)
@@ -199,25 +200,29 @@
                   call add_sm_ei(au,ad,aub,adb,jq,irow,jdof1,jdof2,
      &                 s(jj,ll),sm(jj,ll),jj,ll)
                endif
-            elseif((jdof1.ne.0).or.(jdof2.ne.0)) then
+            elseif((jdof1.gt.0).or.(jdof2.gt.0)) then
 !
 !              idof1: genuine DOF
 !              idof2: nominal DOF of the SPC/MPC
 !
-               if(jdof1.eq.0) then
+               if(jdof1.le.0) then
                   idof1=jdof2
-                  idof2=(node1-1)*8+k
+c                  idof2=(node1-1)*8+k
+                  idof2=jdof1
                else
                   idof1=jdof1
-                  idof2=(node2-1)*8+m
+c                  idof2=(node2-1)*8+m
+                  idof2=jdof2
                endif
                if(nmpc.gt.0) then
-                  call nident(ikmpc,idof2,nmpc,id)
-                  if((id.gt.0).and.(ikmpc(id).eq.idof2)) then
+c                  call nident(ikmpc,idof2,nmpc,id)
+c                  if((id.gt.0).and.(ikmpc(id).eq.idof2)) then
+                  if(idof2.ne.2*(idof2/2)) then
 !
 !                    regular DOF / MPC
 !
-                     id=ilmpc(id)
+c                     id=ilmpc(id)
+                     id=(-idof2+1)/2
                      ist=ipompc(id)
                      index=nodempc(3,ist)
                      if(index.eq.0) cycle
@@ -225,7 +230,7 @@
                         idof2=nactdof(nodempc(2,index),nodempc(1,index))
                         value=-coefmpc(index)*s(jj,ll)/coefmpc(ist)
                         if(idof1.eq.idof2) value=2.d0*value
-                        if(idof2.ne.0) then
+                        if(idof2.gt.0) then
                            if(stiffonly(1)) then
                               call add_sm_st(au,ad,jq,irow,idof1,
      &                             idof2,value,i0,i0)
@@ -251,24 +256,31 @@ c
                if(rhsi) then
                elseif(nmethod.eq.2) then
                   value=s(jj,ll)
-                  call nident(ikboun,idof2,nboun,id)
-                  icolumn=neq(2)+ilboun(id)
+c                  call nident(ikboun,idof2,nboun,id)
+c                  icolumn=neq(2)+ilboun(id)
+                  icolumn=neq(2)-idof2/2
                   call add_bo_st(au,jq,irow,idof1,icolumn,value)
                endif
             else
-               idof1=(node1-1)*8+k
-               idof2=(node2-1)*8+m
+c               idof1=(node1-1)*8+k
+c               idof2=(node2-1)*8+m
+               idof1=jdof1
+               idof2=jdof2
                mpc1=0
                mpc2=0
                if(nmpc.gt.0) then
-                  call nident(ikmpc,idof1,nmpc,id1)
-                  if((id1.gt.0).and.(ikmpc(id1).eq.idof1)) mpc1=1
-                  call nident(ikmpc,idof2,nmpc,id2)
-                  if((id2.gt.0).and.(ikmpc(id2).eq.idof2)) mpc2=1
+c                  call nident(ikmpc,idof1,nmpc,id1)
+c                  if((id1.gt.0).and.(ikmpc(id1).eq.idof1)) mpc1=1
+c                  call nident(ikmpc,idof2,nmpc,id2)
+c                  if((id2.gt.0).and.(ikmpc(id2).eq.idof2)) mpc2=1
+                  if(idof1.ne.2*(idof1/2)) mpc1=1
+                  if(idof2.ne.2*(idof2/2)) mpc2=1
                endif
                if((mpc1.eq.1).and.(mpc2.eq.1)) then
-                  id1=ilmpc(id1)
-                  id2=ilmpc(id2)
+c                  id1=ilmpc(id1)
+c                  id2=ilmpc(id2)
+                  id1=(-idof1+1)/2
+                  id2=(-idof2+1)/2
                   if(id1.eq.id2) then
 !
 !                    MPC id1 / MPC id1
@@ -285,7 +297,7 @@ c
      &                                   nodempc(1,index2))
                            value=coefmpc(index1)*coefmpc(index2)*
      &                          s(jj,ll)/coefmpc(ist)/coefmpc(ist)
-                           if((idof1.ne.0).and.(idof2.ne.0)) then
+                           if((idof1.gt.0).and.(idof2.gt.0)) then
                               if(stiffonly(1)) then
                                  call add_sm_st(au,ad,jq,irow,
      &                             idof1,idof2,value,i0,i0)
@@ -329,7 +341,7 @@ c
                            value=coefmpc(index1)*coefmpc(index2)*
      &                          s(jj,ll)/coefmpc(ist1)/coefmpc(ist2)
                            if(idof1.eq.idof2) value=2.d0*value
-                           if((idof1.ne.0).and.(idof2.ne.0)) then
+                           if((idof1.gt.0).and.(idof2.gt.0)) then
                               if(stiffonly(1)) then
                                  call add_sm_st(au,ad,jq,irow,
      &                             idof1,idof2,value,i0,i0)
@@ -360,19 +372,22 @@ c
 !            distributed forces
 !
              if(idist.ne.0) then
-                if(jdof1.eq.0) then
+                if(jdof1.le.0) then
                    if(nmpc.ne.0) then
-                      idof1=(node1-1)*8+k
-                      call nident(ikmpc,idof1,nmpc,id)
-                      if((id.gt.0).and.(ikmpc(id).eq.idof1)) then
-                         id=ilmpc(id)
+c                      idof1=(node1-1)*8+k
+                      idof1=jdof1
+c                      call nident(ikmpc,idof1,nmpc,id)
+c                      if((id.gt.0).and.(ikmpc(id).eq.idof1)) then
+                      if(idof1.ne.2*(idof1/2)) then
+c                         id=ilmpc(id)
+                         id=(-idof1+1)/2
                          ist=ipompc(id)
                          index=nodempc(3,ist)
                          if(index.eq.0) cycle
                          do
                             jdof1=nactdof(nodempc(2,index),
      &                           nodempc(1,index))
-                            if(jdof1.ne.0) then
+                            if(jdof1.gt.0) then
                                fext(jdof1)=fext(jdof1)
      &                              -coefmpc(index)*ff(jj)
      &                              /coefmpc(ist)
@@ -432,7 +447,7 @@ c
            cycle
         endif
 !
-        call e_c3d_th(co,nk,kon,lakon(i),s,sm,
+        call e_c3d_th(co,nk,kon,lakon(i),st,smt,
      &  ff,i,nmethod,rhcon,nrhcon,ielmat,ielorien,norien,orab,
      &  ntmat_,t0,t1,ithermal,vold,iperturb,nelemload,
      &  sideload,xload,nload,idist,iexpl,dtime,
@@ -441,7 +456,7 @@ c
      &  xstiff,xloadold,reltime,ipompc,nodempc,coefmpc,nmpc,ikmpc,
      &  ilmpc,springarea,plkcon,nplkcon,npmat_,ncmat_,elcon,nelcon,
      &  lakon,pslavsurf,pmastsurf,mortar,clearini,plicon,nplicon,
-     &  ipkon,ielprop,prop)
+     &  ipkon,ielprop,prop,iponoel,inoel)
 !
         do jj=1,nope
 !
@@ -459,46 +474,50 @@ c
 !
 !           check whether one of the DOF belongs to a SPC or MPC
 !
-            if((jdof1.ne.0).and.(jdof2.ne.0)) then
+            if((jdof1.gt.0).and.(jdof2.gt.0)) then
                if(stiffonly(2)) then
                   call add_sm_st(au,ad,jq,irow,jdof1,jdof2,
-     &                 s(jj,ll),jj,ll)
+     &                 st(jj,ll),jj,ll)
                else
                   call add_sm_ei(au,ad,aub,adb,jq,irow,jdof1,jdof2,
-     &                 s(jj,ll),sm(jj,ll),jj,ll)
+     &                 st(jj,ll),smt(jj,ll),jj,ll)
                endif
-            elseif((jdof1.ne.0).or.(jdof2.ne.0)) then
+            elseif((jdof1.gt.0).or.(jdof2.gt.0)) then
 !
 !              idof1: genuine DOF
 !              idof2: nominal DOF of the SPC/MPC
 !
-               if(jdof1.eq.0) then
+               if(jdof1.le.0) then
                   idof1=jdof2
-                  idof2=(node1-1)*8
+c                  idof2=(node1-1)*8
+                  idof2=jdof1
                else
                   idof1=jdof1
-                  idof2=(node2-1)*8
+c                  idof2=(node2-1)*8
+                  idof2=jdof2
                endif
                if(nmpc.gt.0) then
-                  call nident(ikmpc,idof2,nmpc,id)
-                  if((id.gt.0).and.(ikmpc(id).eq.idof2)) then
+c                  call nident(ikmpc,idof2,nmpc,id)
+c                  if((id.gt.0).and.(ikmpc(id).eq.idof2)) then
+                  if(idof2.ne.2*(idof2/2)) then
 !
 !                    regular DOF / MPC
 !
-                     id=ilmpc(id)
+c                     id=ilmpc(id)
+                     id=(-idof2+1)/2
                      ist=ipompc(id)
                      index=nodempc(3,ist)
                      if(index.eq.0) cycle
                      do
                         idof2=nactdof(nodempc(2,index),nodempc(1,index))
-                        value=-coefmpc(index)*s(jj,ll)/coefmpc(ist)
+                        value=-coefmpc(index)*st(jj,ll)/coefmpc(ist)
                         if(idof1.eq.idof2) value=2.d0*value
-                        if(idof2.ne.0) then
+                        if(idof2.gt.0) then
                            if(stiffonly(2)) then
                               call add_sm_st(au,ad,jq,irow,idof1,
      &                             idof2,value,i0,i0)
                            else
-                              valu2=-coefmpc(index)*sm(jj,ll)/
+                              valu2=-coefmpc(index)*smt(jj,ll)/
      &                               coefmpc(ist)
 !
                               if(idof1.eq.idof2) valu2=2.d0*valu2
@@ -518,25 +537,32 @@ c
 !
                if(rhsi) then
                elseif(nmethod.eq.2) then
-                  value=s(jj,ll)
-                  call nident(ikboun,idof2,nboun,id)
-                  icolumn=neq(2)+ilboun(id)
+                  value=st(jj,ll)
+c                  call nident(ikboun,idof2,nboun,id)
+c                  icolumn=neq(2)+ilboun(id)
+                  icolumn=neq(2)-idof2/2
                   call add_bo_st(au,jq,irow,idof1,icolumn,value)
                endif
             else
-               idof1=(node1-1)*8
-               idof2=(node2-1)*8
+c               idof1=(node1-1)*8
+c               idof2=(node2-1)*8
+               idof1=jdof1
+               idof2=jdof2
                mpc1=0
                mpc2=0
                if(nmpc.gt.0) then
-                  call nident(ikmpc,idof1,nmpc,id1)
-                  if((id1.gt.0).and.(ikmpc(id1).eq.idof1)) mpc1=1
-                  call nident(ikmpc,idof2,nmpc,id2)
-                  if((id2.gt.0).and.(ikmpc(id2).eq.idof2)) mpc2=1
+c                  call nident(ikmpc,idof1,nmpc,id1)
+c                  if((id1.gt.0).and.(ikmpc(id1).eq.idof1)) mpc1=1
+c                  call nident(ikmpc,idof2,nmpc,id2)
+c                  if((id2.gt.0).and.(ikmpc(id2).eq.idof2)) mpc2=1
+                  if(idof1.ne.2*(idof1/2)) mpc1=1
+                  if(idof2.ne.2*(idof2/2)) mpc2=1
                endif
                if((mpc1.eq.1).and.(mpc2.eq.1)) then
-                  id1=ilmpc(id1)
-                  id2=ilmpc(id2)
+c                  id1=ilmpc(id1)
+c                  id2=ilmpc(id2)
+                  id1=(-idof1+1)/2
+                  id2=(-idof2+1)/2
                   if(id1.eq.id2) then
 !
 !                    MPC id1 / MPC id1
@@ -552,14 +578,14 @@ c
                            idof2=nactdof(nodempc(2,index2),
      &                                   nodempc(1,index2))
                            value=coefmpc(index1)*coefmpc(index2)*
-     &                          s(jj,ll)/coefmpc(ist)/coefmpc(ist)
-                           if((idof1.ne.0).and.(idof2.ne.0)) then
+     &                          st(jj,ll)/coefmpc(ist)/coefmpc(ist)
+                           if((idof1.gt.0).and.(idof2.gt.0)) then
                               if(stiffonly(2)) then
                                  call add_sm_st(au,ad,jq,irow,
      &                             idof1,idof2,value,i0,i0)
                               else
                                  valu2=coefmpc(index1)*coefmpc(index2)*
-     &                             sm(jj,ll)/coefmpc(ist)/coefmpc(ist)
+     &                             smt(jj,ll)/coefmpc(ist)/coefmpc(ist)
                                  call add_sm_ei(au,ad,aub,adb,jq,
      &                             irow,idof1,idof2,value,valu2,i0,i0)
                               endif
@@ -595,15 +621,15 @@ c
                            idof2=nactdof(nodempc(2,index2),
      &                                   nodempc(1,index2))
                            value=coefmpc(index1)*coefmpc(index2)*
-     &                          s(jj,ll)/coefmpc(ist1)/coefmpc(ist2)
+     &                          st(jj,ll)/coefmpc(ist1)/coefmpc(ist2)
                            if(idof1.eq.idof2) value=2.d0*value
-                           if((idof1.ne.0).and.(idof2.ne.0)) then
+                           if((idof1.gt.0).and.(idof2.gt.0)) then
                               if(stiffonly(2)) then
                                  call add_sm_st(au,ad,jq,irow,
      &                             idof1,idof2,value,i0,i0)
                               else
                                  valu2=coefmpc(index1)*coefmpc(index2)*
-     &                             sm(jj,ll)/coefmpc(ist1)/coefmpc(ist2)
+     &                            smt(jj,ll)/coefmpc(ist1)/coefmpc(ist2)
 !
                                  if(idof1.eq.idof2) valu2=2.d0*valu2
 !
@@ -628,19 +654,22 @@ c
 !            distributed forces
 !
              if(idist.ne.0) then
-                if(jdof1.eq.0) then
+                if(jdof1.le.0) then
                    if(nmpc.ne.0) then
-                      idof1=(node1-1)*8
-                      call nident(ikmpc,idof1,nmpc,id)
-                      if((id.gt.0).and.(ikmpc(id).eq.idof1)) then
-                         id=ilmpc(id)
+c                      idof1=(node1-1)*8
+                      idof1=jdof1
+c                      call nident(ikmpc,idof1,nmpc,id)
+c                      if((id.gt.0).and.(ikmpc(id).eq.idof1)) then
+                      if(idof1.ne.2*(idof1/2)) then
+c                         id=ilmpc(id)
+                         id=(-idof1+1)/2
                          ist=ipompc(id)
                          index=nodempc(3,ist)
                          if(index.eq.0) cycle
                          do
                             jdof1=nactdof(nodempc(2,index),
      &                           nodempc(1,index))
-                            if(jdof1.ne.0) then
+                            if(jdof1.gt.0) then
                                fext(jdof1)=fext(jdof1)
      &                              -coefmpc(index)*ff(jj)
      &                              /coefmpc(ist)
