@@ -62,9 +62,9 @@
 !
       real*8 co(3,*),xboun(*),coefmpc(*),xforc(*),xload(2,*),p1(3),
      &  p2(3),ad(*),au(*),bodyf(3),fext(*),xloadold(2,*),value,
-     &  t0(*),t1(*),prestr(6,mi(1),*),vold(0:mi(2),*),s(100,100),
-     &  ff(100),
-     &  sti(6,mi(1),*),sm(100,100),stx(6,mi(1),*),adb(*),aub(*),
+     &  t0(*),t1(*),prestr(6,mi(1),*),vold(0:mi(2),*),s(60,60),
+     &  ff(60),
+     &  sti(6,mi(1),*),sm(60,60),stx(6,mi(1),*),adb(*),aub(*),
      &  elcon(0:ncmat_,ntmat_,*),rhcon(0:1,ntmat_,*),reltime,
      &  alcon(0:6,ntmat_,*),physcon(*),cocon(0:6,ntmat_,*),
      &  shcon(0:3,ntmat_,*),alzero(*),orab(7,*),xbody(7,*),cgr(4,*),
@@ -143,15 +143,15 @@
 !     
 !     check whether one of the DOF belongs to a SPC or MPC
 !     
-              if((jdof1.ne.0).and.(jdof2.ne.0)) then
+              if((jdof1.gt.0).and.(jdof2.gt.0)) then
                  call add_sm_st_as(au,ad,jq,irow,jdof1,jdof2,
      &                s(jj,ll),jj,ll,nzs)
-              elseif((jdof1.ne.0).or.(jdof2.ne.0)) then
+              elseif((jdof1.gt.0).or.(jdof2.gt.0)) then
 !     
 !     idof1: genuine DOF
 !     idof2: nominal DOF of the SPC/MPC
 !     
-                 if(jdof1.eq.0) then
+                 if(jdof1.le.0) then
                     idof1=(node1-1)*8+k
                     idof2=jdof2
                     if(nmpc.gt.0) then
@@ -168,7 +168,7 @@
                              idof1=nactdof(nodempc(2,index),
      &                              nodempc(1,index))
                              value=-coefmpc(index)*s(jj,ll)/coefmpc(ist)
-                             if(idof1.ne.0) then
+                             if(idof1.gt.0) then
                                 call add_sm_st_as(au,ad,jq,irow,idof1,
      &                               idof2,value,i0,i0,nzs)
                              endif
@@ -195,7 +195,7 @@
                              idof2=nactdof(nodempc(2,index),
      &                             nodempc(1,index))
                              value=-coefmpc(index)*s(jj,ll)/coefmpc(ist)
-                             if(idof2.ne.0) then
+                             if(idof2.gt.0) then
                                 call add_sm_st_as(au,ad,jq,irow,idof1,
      &                               idof2,value,i0,i0,nzs)
                              endif
@@ -248,7 +248,7 @@ c                             value=coefmpc(index1)*coefmpc(index2)*
 c     &                            s(jj,ll)/coefmpc(ist)/coefmpc(ist)
                              value=coefmpc(index1)*coefmpc(index2)*
      &                            s(jj,ll)/coefmpc(ist1)/coefmpc(ist2)
-                             if((idof1.ne.0).and.(idof2.ne.0)) then
+                             if((idof1.gt.0).and.(idof2.gt.0)) then
                                 call add_sm_st_as(au,ad,jq,irow,
      &                               idof1,idof2,value,i0,i0,nzs)
                              endif
@@ -284,7 +284,7 @@ c     &                            s(jj,ll)/coefmpc(ist)/coefmpc(ist)
      &                            nodempc(1,index2))
                              value=coefmpc(index1)*coefmpc(index2)*
      &                            s(jj,ll)/coefmpc(ist1)/coefmpc(ist2)
-                             if((idof1.ne.0).and.(idof2.ne.0)) then
+                             if((idof1.gt.0).and.(idof2.gt.0)) then
                                 call add_sm_st_as(au,ad,jq,irow,
      &                               idof1,idof2,value,i0,i0,nzs)
                              endif
@@ -346,15 +346,15 @@ c     &                            s(jj,ll)/coefmpc(ist)/coefmpc(ist)
 !     
 !     check whether one of the DOF belongs to a SPC or MPC
 !     
-              if((jdof1.ne.0).and.(jdof2.ne.0)) then
+              if((jdof1.gt.0).and.(jdof2.gt.0)) then
                  call add_sm_st_as(au,ad,jq,irow,jdof1,jdof2,
      &                s(jj,ll),jj,ll,nzs)
-              elseif((jdof1.ne.0).or.(jdof2.ne.0)) then
+              elseif((jdof1.gt.0).or.(jdof2.gt.0)) then
 !     
 !     idof1: genuine DOF
 !     idof2: nominal DOF of the SPC/MPC
 !     
-                 if(jdof1.eq.0) then
+                 if(jdof1.le.0) then
                     idof1=(node1-1)*8
                     idof2=jdof2
                     if(nmpc.gt.0) then
@@ -371,7 +371,7 @@ c     &                            s(jj,ll)/coefmpc(ist)/coefmpc(ist)
                              idof1=nactdof(nodempc(2,index),
      &                              nodempc(1,index))
                              value=-coefmpc(index)*s(jj,ll)/coefmpc(ist)
-                             if(idof1.ne.0) then
+                             if(idof1.gt.0) then
                                 call add_sm_st_as(au,ad,jq,irow,idof1,
      &                               idof2,value,i0,i0,nzs)
                              endif
@@ -398,7 +398,7 @@ c     &                            s(jj,ll)/coefmpc(ist)/coefmpc(ist)
                              idof2=nactdof(nodempc(2,index),
      &                             nodempc(1,index))
                              value=-coefmpc(index)*s(jj,ll)/coefmpc(ist)
-                             if(idof2.ne.0) then
+                             if(idof2.gt.0) then
                                 call add_sm_st_as(au,ad,jq,irow,idof1,
      &                               idof2,value,i0,i0,nzs)
                              endif
@@ -451,7 +451,7 @@ c                             value=coefmpc(index1)*coefmpc(index2)*
 c     &                            s(jj,ll)/coefmpc(ist)/coefmpc(ist)
                              value=coefmpc(index1)*coefmpc(index2)*
      &                            s(jj,ll)/coefmpc(ist1)/coefmpc(ist2)
-                             if((idof1.ne.0).and.(idof2.ne.0)) then
+                             if((idof1.gt.0).and.(idof2.gt.0)) then
                                 call add_sm_st_as(au,ad,jq,irow,
      &                               idof1,idof2,value,i0,i0,nzs)
                              endif
@@ -487,7 +487,7 @@ c     &                            s(jj,ll)/coefmpc(ist)/coefmpc(ist)
      &                            nodempc(1,index2))
                              value=coefmpc(index1)*coefmpc(index2)*
      &                            s(jj,ll)/coefmpc(ist1)/coefmpc(ist2)
-                             if((idof1.ne.0).and.(idof2.ne.0)) then
+                             if((idof1.gt.0).and.(idof2.gt.0)) then
                                 call add_sm_st_as(au,ad,jq,irow,
      &                               idof1,idof2,value,i0,i0,nzs)
                              endif
