@@ -30,7 +30,8 @@
      &  rhsi,intscheme,mcs,coriolis,ibody,xloadold,reltime,ielcs,
      &  veold,springarea,thicke,integerglob,doubleglob,
      &  tieset,istartset,iendset,ialset,ntie,nasym,pslavsurf,pmastsurf,
-     &  mortar,clearini,ielprop,prop,ne0,kscale)
+     &  mortar,clearini,ielprop,prop,ne0,kscale,xstateini,xstate,
+     &  nstate_)
 !
 !     filling the stiffness matrix in spare matrix format (sm)
 !     for cyclic symmetry calculations
@@ -61,12 +62,12 @@
 !
       real*8 co(3,*),xboun(*),coefmpc(*),xforc(*),xload(2,*),p1(3),
      &  p2(3),ad(*),au(*),bodyf(3),bb(*),xbody(7,*),cgr(4,*),prop(*),
-     &  t0(*),t1(*),prestr(6,mi(1),*),vold(0:mi(2),*),s(100,100),
-     &  ff(100),
-     &  sti(6,mi(1),*),sm(100,100),stx(6,mi(1),*),adb(*),aub(*),
+     &  t0(*),t1(*),prestr(6,mi(1),*),vold(0:mi(2),*),s(60,60),
+     &  xstate(nstate_,mi(1),*),xstateini(nstate_,mi(1),*),ff(60),
+     &  sti(6,mi(1),*),sm(60,60),stx(6,mi(1),*),adb(*),aub(*),
      &  elcon(0:ncmat_,ntmat_,*),rhcon(0:1,ntmat_,*),xloadold(2,*),
      &  alcon(0:6,ntmat_,*),cs(17,*),alzero(*),orab(7,*),reltime,
-     &  springarea(2,*),plicon(0:2*npmat_,ntmat_,*),xstate,xstateini,
+     &  springarea(2,*),plicon(0:2*npmat_,ntmat_,*),
      &  plkcon(0:2*npmat_,ntmat_,*),thicke(mi(3),*),doubleglob(*),
      &  xstiff(27,mi(1),*),pi,theta,ti,tr,veold(0:mi(2),*),om,valu2,
      &  value,dtime,walue,walu2,time,ttime,clearini(3,9,*),
@@ -220,31 +221,35 @@ c    Bernhardi end
 !
 !           check whether one of the DOF belongs to a SPC or MPC
 !
-            if((jdof1.ne.0).and.(jdof2.ne.0)) then
+            if((jdof1.gt.0).and.(jdof2.gt.0)) then
                call add_sm_ei(au,ad,aub,adb,jq,irow,jdof1,jdof2,
      &              s(jj,ll),sm(jj,ll),jj,ll)
                call add_sm_ei(au,ad,aub,adb,jq,irow,jdof1+ner,jdof2+ner,
      &              s(jj,ll),sm(jj,ll),jj,ll)
-            elseif((jdof1.ne.0).or.(jdof2.ne.0)) then
+            elseif((jdof1.gt.0).or.(jdof2.gt.0)) then
 !
 !              idof1: genuine DOF
 !              idof2: nominal DOF of the SPC/MPC
 !
-               if(jdof1.eq.0) then
+               if(jdof1.le.0) then
                   idof1=jdof2
-                  idof2=(node1-1)*8+k
+c                  idof2=(node1-1)*8+k
+                  idof2=jdof1
                else
                   idof1=jdof1
-                  idof2=(node2-1)*8+m
+c                  idof2=(node2-1)*8+m
+                  idof2=jdof2
                endif
 !
                if(nmpc.gt.0) then
-                  call nident(ikmpc,idof2,nmpc,id)
-                  if((id.gt.0).and.(ikmpc(id).eq.idof2)) then
+c                  call nident(ikmpc,idof2,nmpc,id)
+c                  if((id.gt.0).and.(ikmpc(id).eq.idof2)) then
+                  if(idof2.ne.2*(idof2/2)) then
 !
 !                    regular DOF / MPC
 !
-                     id1=ilmpc(id)
+c                     id1=ilmpc(id)
+                     id1=(-idof2+1)/2
                      ist=ipompc(id1)
                      index=nodempc(3,ist)
                      if(index.eq.0) cycle
@@ -268,7 +273,7 @@ c                        write(*,*) id1,labmpc(id1)(1:9)
                            enddo
                         endif
                         idof2=nactdof(nodempc(2,index),inode)
-                        if(idof2.ne.0) then
+                        if(idof2.gt.0) then
                            value=-coefmpc(index)*s(jj,ll)/coefmpc(ist)
                            valu2=-coefmpc(index)*sm(jj,ll)/
      &                          coefmpc(ist)
@@ -308,20 +313,26 @@ c                        write(*,*) id1,labmpc(id1)(1:9)
                endif
 !
             else
-               idof1=(node1-1)*8+k
-               idof2=(node2-1)*8+m
+c               idof1=(node1-1)*8+k
+c               idof2=(node2-1)*8+m
+               idof1=jdof1
+               idof2=jdof2
 !
                mpc1=0
                mpc2=0
                if(nmpc.gt.0) then
-                  call nident(ikmpc,idof1,nmpc,id1)
-                  if((id1.gt.0).and.(ikmpc(id1).eq.idof1)) mpc1=1
-                  call nident(ikmpc,idof2,nmpc,id2)
-                  if((id2.gt.0).and.(ikmpc(id2).eq.idof2)) mpc2=1
+c                  call nident(ikmpc,idof1,nmpc,id1)
+c                  if((id1.gt.0).and.(ikmpc(id1).eq.idof1)) mpc1=1
+c                  call nident(ikmpc,idof2,nmpc,id2)
+c                  if((id2.gt.0).and.(ikmpc(id2).eq.idof2)) mpc2=1
+                  if(idof1.ne.2*(idof1/2)) mpc1=1
+                  if(idof2.ne.2*(idof2/2)) mpc2=1
                endif
                if((mpc1.eq.1).and.(mpc2.eq.1)) then
-                  id1=ilmpc(id1)
-                  id2=ilmpc(id2)
+c                  id1=ilmpc(id1)
+c                  id2=ilmpc(id2)
+                  id1=(-idof1+1)/2
+                  id2=(-idof2+1)/2
                   if(id1.eq.id2) then
 !
 !                    MPC id1 / MPC id1
@@ -370,7 +381,7 @@ c                        write(*,*) id1,labmpc(id1)(1:9)
                               enddo
                            endif
                            idof2=nactdof(nodempc(2,index2),inode2)
-                           if((idof1.ne.0).and.(idof2.ne.0)) then
+                           if((idof1.gt.0).and.(idof2.gt.0)) then
                               value=coefmpc(index1)*coefmpc(index2)*
      &                             s(jj,ll)/coefmpc(ist)/coefmpc(ist)
                               valu2=coefmpc(index1)*coefmpc(index2)*
@@ -512,7 +523,7 @@ c                                    walu2=valu2*st
                               enddo
                            endif
                            idof2=nactdof(nodempc(2,index2),inode2)
-                           if((idof1.ne.0).and.(idof2.ne.0)) then
+                           if((idof1.gt.0).and.(idof2.gt.0)) then
                               value=coefmpc(index1)*coefmpc(index2)*
      &                             s(jj,ll)/coefmpc(ist1)/coefmpc(ist2)
                               valu2=coefmpc(index1)*coefmpc(index2)*
