@@ -33,7 +33,7 @@ static ITG *nk1,*kon1,*ipkon1,*ne1,*nodeboun1,*ndirboun1,*nboun1,
     *mi1,*ncmat1_,*mass1,*stiffness1,*buckling1,*rhsi1,*intscheme1,
     *nshcon1,*ncocon1,*istep1,*iinc1,*coriolis1,*ibody1,*nstate1_,
     *integerglob1,*istartset1,*iendset1,*ialset1,*ntie1,*nasym1,
-    *mortar1,*ielprop1,*ne01,num_cpus,*kscale1;
+    *mortar1,*ielprop1,*ne01,num_cpus,*kscale1,*iponoel1,*inoel1;
 
 static double *co1,*xboun1,*coefmpc1,*xforc1,*xload1,*xbody1,*cgr1,
     *ad1=NULL,*au1=NULL,*fext1=NULL,*elcon1,*rhcon1,*alcon1,*alzero1,
@@ -75,7 +75,7 @@ void mafillsmmain(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 	       ITG *istartset,ITG *iendset,ITG *ialset,ITG *ntie,
 	       ITG *nasym,double *pslavsurf,double *pmastsurf,ITG *mortar,
 	       double *clearini,ITG *ielprop,double *prop,ITG *ne0,
-	       double *fnext,ITG *kscale){
+	       double *fnext,ITG *kscale,ITG *iponoel,ITG *inoel){
 
     ITG i,j,mt=mi[1]+1;
       
@@ -203,7 +203,8 @@ void mafillsmmain(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
     doubleglob1=doubleglob;tieset1=tieset;istartset1=istartset;
     iendset1=iendset;ialset1=ialset;ntie1=ntie;nasym1=nasym;
     pslavsurf1=pslavsurf;pmastsurf1=pmastsurf;mortar1=mortar;
-    clearini1=clearini;ielprop1=ielprop;prop1=prop;ne01=ne0;kscale1=kscale;  
+    clearini1=clearini;ielprop1=ielprop;prop1=prop;ne01=ne0;kscale1=kscale;
+    iponoel1=iponoel;inoel1=inoel;  
 
     /* calculating the stiffness/mass */
     
@@ -441,7 +442,7 @@ void *mafillsmmt(ITG *i){
             xstateini1,xstate1,thicke1,integerglob1,doubleglob1,
 	    tieset1,istartset1,iendset1,ialset1,ntie1,nasym1,pslavsurf1,
 	    pmastsurf1,mortar1,clearini1,ielprop1,prop1,ne01,
-	    &fnext1[indexfnext],&nea,&neb,kscale1));
+	    &fnext1[indexfnext],&nea,&neb,kscale1,iponoel1,inoel1));
 
     return NULL;
 }
