@@ -33,15 +33,16 @@ static ITG *nk1,*kon1,*ipkon1,*ne1,*nodeboun1,*ndirboun1,*nboun1,
     *mi1,*ncmat1_,*mass1,*stiffness1,*buckling1,*rhsi1,*intscheme1,
     *nshcon1,*ncocon1,*istep1,*iinc1,*coriolis1,*ibody1,*nstate1_,
     *integerglob1,*istartset1,*iendset1,*ialset1,*ntie1,*nasym1,
-    *mortar1,*ielprop1,*ne01,num_cpus,*ndesi1,*nodedesi1,*ndirdesi1;
+    *mortar1,*ielprop1,*ne01,num_cpus,*ndesi1,*nodedesi1,
+    *nzss1,*jqs1,*irows1,*icoordinate1,*istartelem1,*ialelem1;
 
 static double *co1,*xboun1,*coefmpc1,*xforc1,*xload1,*xbody1,*cgr1,
-    *ad1=NULL,*au1=NULL,*elcon1,*rhcon1,*alcon1,*alzero1,
-    *orab1,*t01,*t11,*prestr1,*vold1,*sti1,*stx1,*adb1=NULL,*aub1=NULL,
+    *elcon1,*rhcon1,*alcon1,*alzero1,*xdesi1,*v1,
+    *orab1,*t01,*t11,*prestr1,*vold1,*sti1,*stx1,
     *plicon1,*plkcon1,*xstiff1,*dtime1,*physcon1,*shcon1,*cocon1,
     *ttime1,*time1,*xloadold1,*reltime1,*veold1,*springarea1,
     *xstateini1,*xstate1,*thicke1,*doubleglob1,*pslavsurf1,*pmastsurf1,
-    *clearini1,*prop1,*fnext1=NULL,*distmin1,*dfextminds1;
+    *clearini1,*prop1,*distmin1,*df1,*dfminds1,*dxstiff1;
 
 void mafillsmmain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 	       ITG *ne,ITG *nodeboun,ITG *ndirboun,double *xboun, 
@@ -76,9 +77,11 @@ void mafillsmmain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 	       ITG *nasym,double *pslavsurf,double *pmastsurf,ITG *mortar,
 	       double *clearini,ITG *ielprop,double *prop,ITG *ne0,
                double *fnext,double *distmin,ITG *ndesi,ITG *nodedesi,
-	       ITG *ndirdesi,double *dfextminds){
+	       double *df,ITG *nzss,ITG *jqs,ITG *irows,
+	       ITG *icoordinate,double *dxstiff,double *xdesi,
+	       ITG *istartelem,ITG *ialelem,double *v){
 	       
-    ITG i,j,mt=mi[1]+1;
+    ITG i,j;
      
     /* variables for multithreading procedure */
     
@@ -137,33 +140,10 @@ void mafillsmmain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
     
     pthread_t tid[num_cpus];
 
-    /* determine nzl */
-
-    *nzl=0;
-    for(i=neq[1];i>=1;i--){
-	if(icol[i-1]>0){
-	    *nzl=i;
-	    break;
-	}
-    }
-
     /* allocating fields for mass and stiffness matrix and sensitivity matrix */
     
-    NNEW(dfextminds1,double,num_cpus**ndesi**neq);
-    
-    if(*buckling!=1){
-	NNEW(ad1,double,num_cpus*neq[1]);
-	NNEW(au1,double,num_cpus*nzs[2]);
-    }
-
-    if((mass[0]==1)||(mass[1]==1)||(*buckling==1)){
-	NNEW(adb1,double,num_cpus*neq[1]);
-	NNEW(aub1,double,num_cpus*nzs[1]);
-    }
-
-    if(*nmethod==4){
-	NNEW(fnext1,double,num_cpus*mt**nk);
-    }
+    NNEW(df1,double,num_cpus**nzss);
+    NNEW(dfminds1,double,num_cpus*60**ndesi);
 
     /* allocating memory for nmethod; if the Jacobian determinant
        in any of the elements is nonpositive, nmethod is set to
@@ -203,11 +183,13 @@ void mafillsmmain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
     iendset1=iendset;ialset1=ialset;ntie1=ntie;nasym1=nasym;
     pslavsurf1=pslavsurf;pmastsurf1=pmastsurf;mortar1=mortar;
     clearini1=clearini;ielprop1=ielprop;prop1=prop;ne01=ne0;
-    distmin1=distmin;ndesi1=ndesi;nodedesi1=nodedesi;ndirdesi1=ndirdesi;
+    distmin1=distmin;ndesi1=ndesi;nodedesi1=nodedesi;v1=v;
+    nzss1=nzss;jqs1=jqs;irows1=irows;icoordinate1=icoordinate;
+    dxstiff1=dxstiff;xdesi1=xdesi;istartelem1=istartelem;ialelem1=ialelem;
 
-    /* calculating the stiffness/mass */
+    /* calculating the stiffness/mass sensitivity */
     
-    printf(" Using up to %" ITGFORMAT " cpu(s) for the stiffness/mass calculation.\n\n", num_cpus);
+    printf(" Using up to %" ITGFORMAT " cpu(s) for the stiffness/mass sensitivity calculation.\n\n", num_cpus);
     
     /* create threads and wait */
     
@@ -220,88 +202,6 @@ void mafillsmmain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
     
     SFREE(ithread);
 
-    /* copying and accumulating the stiffnes and/or mass matrix */
-
-    if(*buckling!=1){
-	for(i=0;i<neq[1];i++){
-	    ad[i]=ad1[i];
-	}
-	for(i=0;i<neq[1];i++){
-	    for(j=1;j<num_cpus;j++){
-		ad[i]+=ad1[i+j*neq[1]];
-	    }
-	}
-	SFREE(ad1);
-
-	for(i=0;i<nzs[2];i++){
-	    au[i]=au1[i];
-	}
-	for(i=0;i<nzs[2];i++){
-	    for(j=1;j<num_cpus;j++){
-		au[i]+=au1[i+j*nzs[2]];
-	    }
-	}
-	SFREE(au1);
-    }	
-
-    if(mass[1]==1){
-	for(i=neq[0];i<neq[1];i++){
-	    adb[i]=adb1[i];
-	}
-	for(i=neq[0];i<neq[1];i++){
-	    for(j=1;j<num_cpus;j++){
-		adb[i]+=adb1[i+j*neq[1]];
-	    }
-	}
-	//	SFREE(adb1);
-
-	for(i=nzs[0];i<nzs[1];i++){
-	    aub[i]=aub1[i];
-	}
-	for(i=nzs[0];i<nzs[1];i++){
-	    for(j=1;j<num_cpus;j++){
-		aub[i]+=aub1[i+j*nzs[1]];
-	    }
-	}
-	//	SFREE(aub1);
-    }
-    if((mass[0]==1)||(*buckling==1)){
-	for(i=0;i<neq[0];i++){
-	    adb[i]=adb1[i];
-	}
-	for(i=0;i<neq[0];i++){
-	    for(j=1;j<num_cpus;j++){
-		adb[i]+=adb1[i+j*neq[1]];
-	    }
-	}
-	//	SFREE(adb1);
-
-	for(i=0;i<nzs[0];i++){
-	    aub[i]=aub1[i];
-	}
-	for(i=0;i<nzs[0];i++){
-	    for(j=1;j<num_cpus;j++){
-		aub[i]+=aub1[i+j*nzs[1]];
-	    }
-	}
-	//	SFREE(aub1);
-    }
-    if((mass[0]==1)||(mass[1]==1)||(*buckling==1)){
-      SFREE(adb1);SFREE(aub1);
-    }
-
-    if(*nmethod==4){
-	for(i=0;i<mt**nk;i++){
-	    fnext[i]=fnext1[i];
-	}
-	for(i=0;i<mt**nk;i++){
-	    for(j=1;j<num_cpus;j++){
-		fnext[i]+=fnext1[i+j*mt**nk];
-	    }
-	}
-	SFREE(fnext1);
-    }
-
     for(j=0;j<num_cpus;j++){
 	if(nmethod1[j]==0){
 	    *nmethod=0;
@@ -309,16 +209,17 @@ void mafillsmmain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 	}
     }
     
-    /* passing of dfextminds   */
-    for(i=0;i<*ndesi*neq[1];i++){
-	dfextminds[i]=dfextminds1[i];
+    /* passing of df */
+
+    for(i=0;i<*nzss;i++){
+	df[i]=df1[i];
 	}
-    for(i=0;i<*ndesi*neq[1];i++){
+    for(i=0;i<*nzss;i++){
 	for(j=1;j<num_cpus;j++){
-	    dfextminds[i]+=dfextminds1[i+j**ndesi*neq[1]];
+	    df[i]+=df1[i+j**nzss];
 	}
     }
-    SFREE(dfextminds1);
+    SFREE(df1);SFREE(dfminds1);
         
         return;
 
@@ -328,43 +229,16 @@ void mafillsmmain_se(double *co,ITG *nk,ITG *kon,ITG *ipkon,char *lakon,
 
 void *mafillsmsemt(ITG *i){
 
-    ITG indexad,indexau,indexfext,indexadb,indexaub,nea,neb,nedelta,indexfnext;
+    ITG indexdf,indexdfminds,nea,neb,nedelta;
 
-    indexad=0;
-    indexau=0;
-    indexfext=0;
-    indexadb=0;
-    indexaub=0;
-    indexfnext=0;
-
-    if(*buckling1!=1){
-	indexad=*i*neq1[1];
-	indexau=*i*nzs1[2];
-    }
-    if(*rhsi1==1){
-	indexfext=*i*neq1[1];
-    }
-    if(mass1[1]==1){
-	indexadb=*i*neq1[1];
-	indexaub=*i*nzs1[1];
-    }else if((mass1[0]==1)||(*buckling1==1)){
-	indexadb=*i*neq1[0];
-	indexaub=*i*nzs1[0];
-    }
-    if(nmethod1[0]==4){
-	indexfnext=*i*(mi1[1]+1)**nk1;
-    }
-    
-// ceil -> floor
+    indexdf=*i**nzss1;
+    indexdfminds=*i*60**ndesi1;
 
     nedelta=(ITG)floor(*ne1/(double)num_cpus);
     nea=*i*nedelta+1;
     neb=(*i+1)*nedelta;
-// next line! -> all parallel sections
     if((*i==num_cpus-1)&&(neb<*ne1)) neb=*ne1;
 
-    printf("i=%d,nea=%d,neb=%d\n",*i,nea,neb);
-
     FORTRAN(mafillsmse,(co1,kon1,ipkon1,lakon1,ne1,ipompc1,nodempc1,
 	    coefmpc1,nmpc1,nelemload1,sideload1,xload1,nload1,xbody1,
 	    ipobody1,nbody1,cgr1,nactdof1,neq1,&nmethod1[*i],ikmpc1,
@@ -378,7 +252,8 @@ void *mafillsmsemt(ITG *i){
             thicke1,integerglob1,doubleglob1,tieset1,istartset1,iendset1,
 	    ialset1,ntie1,nasym1,pslavsurf1,pmastsurf1,mortar1,clearini1,
 	    ielprop1,prop1,ne01,&nea,&neb,distmin1,ndesi1,nodedesi1,
-	    ndirdesi1,dfextminds1));
+	    df1,jqs1,irows1,&dfminds1[indexdfminds],
+	    icoordinate1,dxstiff1,xdesi1,istartelem1,ialelem1,v1));
 	    
     return NULL;
 }
