@@ -42,7 +42,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
     ist1,ist2,node1,node2,isubtract,nmast,ifree,istart,istartold,
     index1,index2,m,node,nzs_,ist,kflag,indexe,nope,isize,*mast1=NULL,
     *irow=NULL,icolumn,nmastboun,mt=mi[1]+1,jmax,*next=NULL,nopeold=0,
-      indexeold=0,identical,jstart;
+      indexeold=0,identical,jstart,iatleastonenonzero,idof;
 
   /* the indices in the comments follow FORTRAN convention, i.e. the
      fields start with 1 */
@@ -72,21 +72,30 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	      if (strcmp1(&lakon[8*i+3],"8I")==0)nope=11;
 	      else if(strcmp1(&lakon[8*i+3],"20")==0)nope=20;
 /* Bernhardi end */
-//	      else if(strcmp1(&lakon[8*i+3],"2")==0)nope=26;
 	      else if (strcmp1(&lakon[8*i+3],"8")==0)nope=8;
 	      else if (strcmp1(&lakon[8*i+3],"10")==0)nope=10;
-//	      else if (strcmp1(&lakon[8*i+3],"14")==0)nope=14;
 	      else if ((strcmp1(&lakon[8*i+3],"4")==0)||
 		       (strcmp1(&lakon[8*i+2],"4")==0)) nope=4;
 	      else if (strcmp1(&lakon[8*i+3],"15")==0)nope=15;
 	      else if (strcmp1(&lakon[8*i+3],"6")==0)nope=6;
 	      else if (strcmp1(&lakon[8*i],"E")==0){
 		  if((strcmp1(&lakon[8*i+6],"C")==0)&&(*mortar==1)){
-//		  nope=kon[ipkon[i]-1];
+
+                      /* face-to-face contact (all nodes already belong
+                         to other elements */
+
 		      continue;
-		  }else{
+		  }else if(strcmp1(&lakon[8*i+6],"F")!=0){
+
+                      /* node-to-face contact */
+
 		      lakonl[0]=lakon[8*i+7];
 		      nope=atoi(lakonl)+1;
+		  }else{
+
+                      /* advection elements */
+
+		      continue;
 		  }
 	      }else continue;
 	      
@@ -110,16 +119,13 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	      if(strcmp1(&lakon[8*i],"F")==0)continue;
 	      indexe=ipkon[i];
 	      if(strcmp1(&lakon[8*i+3],"20")==0)nope=20;
-//	      else if(strcmp1(&lakon[8*i+3],"2")==0)nope=26;
 	      else if (strcmp1(&lakon[8*i+3],"8")==0)nope=8;
 	      else if (strcmp1(&lakon[8*i+3],"10")==0)nope=10;
-//	      else if (strcmp1(&lakon[8*i+3],"14")==0)nope=14;
 	      else if (strcmp1(&lakon[8*i+3],"4")==0)nope=4;
 	      else if (strcmp1(&lakon[8*i+3],"15")==0)nope=15;
 	      else if (strcmp1(&lakon[8*i+3],"6")==0)nope=6;
 	      else if (strcmp1(&lakon[8*i],"E")==0){
 		  if((strcmp1(&lakon[8*i+6],"C")==0)&&(*mortar==1)){
-//		  nope=kon[ipkon[i]-1];
 		      continue;
 		  }else{
 		      lakonl[0]=lakon[8*i+7];
@@ -151,15 +157,40 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
       
       for(i=0;i<*nmpc;++i){
 	  if (strcmp1(&labmpc[20*i],"FLUID")==0) continue;
+
+	  iatleastonenonzero=0;
+
 	  index=ipompc[i]-1;
 	  do{
 	      if(nodempc[3*index+1]<4){
-		  nactdof[mt*(nodempc[3*index]-1)+nodempc[3*index+1]]=1;
+		  idof=mt*(nodempc[3*index]-1)+nodempc[3*index+1];
+		  if(nactdof[idof]==1){
+		      iatleastonenonzero=1;
+		  }else{
+		      nactdof[idof]=1;
+		  }
+//		  nactdof[mt*(nodempc[3*index]-1)+nodempc[3*index+1]]=1;
 	      }
 	      index=nodempc[3*index+2];
 	      if(index==0) break;
 	      index--;
 	  }while(1);
+
+	  if(iatleastonenonzero==1) continue;
+
+          /* if all dofs in the MPC were inactive, keep then inactive
+             (may e.g. belong to network elements) */
+
+	  index=ipompc[i]-1;
+	  do{
+	      if(nodempc[3*index+1]<4){
+		  nactdof[mt*(nodempc[3*index]-1)+nodempc[3*index+1]]=0;
+	      }
+	      index=nodempc[3*index+2];
+	      if(index==0) break;
+	      index--;
+	  }while(1);
+
       }
       
       /* subtracting the SPC and MPC nodes */
@@ -167,14 +198,14 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
       for(i=0;i<*nboun;++i){
 	  if(ndirboun[i]>mi[1]) continue;
 	  if (strcmp1(&typeboun[i],"F")==0) continue;
-	  nactdof[mt*(nodeboun[i]-1)+ndirboun[i]]=0;
+	  nactdof[mt*(nodeboun[i]-1)+ndirboun[i]]=-2*(i+1);
       }
       
       for(i=0;i<*nmpc;++i){
 	  if (strcmp1(&labmpc[20*i],"FLUID")==0) continue;
 	  index=ipompc[i]-1;
 	  if(nodempc[3*index+1]>mi[1]) continue;
-	  nactdof[mt*(nodempc[3*index]-1)+nodempc[3*index+1]]=0;
+	  nactdof[mt*(nodempc[3*index]-1)+nodempc[3*index+1]]=-2*i-1;
       }
       
       /* numbering the active degrees of freedom */
@@ -182,7 +213,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
       neq[0]=0;
       for(i=0;i<*nk;++i){
 	  for(j=1;j<mt;++j){
-	      if(nactdof[mt*i+j]!=0){
+	      if(nactdof[mt*i+j]>0){
 		  if((*ithermal<2)||(*ithermal>=3)){
 		      ++neq[0];
 		      nactdof[mt*i+j]=neq[0];
@@ -195,7 +226,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
       }
       neq[1]=neq[0];
       for(i=0;i<*nk;++i){
-	  if(nactdof[mt*i]!=0){
+	  if(nactdof[mt*i]>0){
 	      if(*ithermal>1){
 		  ++neq[1];
 		  nactdof[mt*i]=neq[1];
@@ -292,35 +323,39 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	  
 	  /* check whether one of the DOF belongs to a SPC or MPC */
 	  
-	  if((jdof1!=0)&&(jdof2!=0)){
+	  if((jdof1>0)&&(jdof2>0)){
 	    insert(ipointer,&mast1,&next,&jdof1,&jdof2,&ifree,&nzs_);
 	  }
-	  else if((jdof1!=0)||(jdof2!=0)){
+	  else if((jdof1>0)||(jdof2>0)){
 	    
 	    /* idof1: genuine DOF
 	       idof2: nominal DOF of the SPC/MPC */
 	    
-	    if(jdof1==0){
+	    if(jdof1<=0){
 	      idof1=jdof2;
-	      idof2=8*node1+k-7;}
+	      idof2=jdof1;}
+//	      idof2=8*node1+k-7;}
 	    else{
 	      idof1=jdof1;
-	      idof2=8*node2+m-7;}
+	      idof2=jdof2;}
+//	      idof2=8*node2+m-7;}
 	    
 	    if(*nmpc>0){
 	      
-	      FORTRAN(nident,(ikmpc,&idof2,nmpc,&id));
-	      if((id>0)&&(ikmpc[id-1]==idof2)){
+//	      FORTRAN(nident,(ikmpc,&idof2,nmpc,&id));
+//	      if((id>0)&&(ikmpc[id-1]==idof2)){
+	      if(idof2!=2*(idof2/2)){
 		
 		/* regular DOF / MPC */
 		
-		id=ilmpc[id-1];
+//		id=ilmpc[id-1];
+		id=(-idof2+1)/2;
 		ist=ipompc[id-1];
 		index=nodempc[3*ist-1];
 		if(index==0) continue;
 		while(1){
 		    idof2=nactdof[mt*(nodempc[3*index-3]-1)+nodempc[3*index-2]];
-		  if(idof2!=0){
+		  if(idof2>0){
 		    insert(ipointer,&mast1,&next,&idof1,&idof2,&ifree,&nzs_);
 		  }
 		  index=nodempc[3*index-1];
@@ -330,6 +365,8 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	      }
 	    }
 
+            /* regular DOF/SPC */
+
             /* boundary stiffness coefficients (for frequency
                and modal dynamic calculations) : x-elements
                on the right of the vertical line */
@@ -340,26 +377,33 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 //        x x x  |x x x
 
 	    if((*nmethod==2)||((*nmethod==4)&&(*iperturb<=1))||((*nmethod>=5)&&(*nmethod<=7))){
-		FORTRAN(nident,(ikboun,&idof2,nboun,&id)); 
-		icolumn=neq[1]+ilboun[id-1];
+//		FORTRAN(nident,(ikboun,&idof2,nboun,&id)); 
+//		icolumn=neq[1]+ilboun[id-1];
+		icolumn=neq[1]-idof2/2;
     	 	insertfreq(ipointer,&mast1,&next,&idof1,&icolumn,&ifree,&nzs_);
 	    }
 	  }
 	  
 	  else{
-	    idof1=8*node1+k-7;
-	    idof2=8*node2+m-7;
+//	    idof1=8*node1+k-7;
+//	    idof2=8*node2+m-7;
+	    idof1=jdof1;
+	    idof2=jdof2;
 	    mpc1=0;
 	    mpc2=0;
 	    if(*nmpc>0){
-	      FORTRAN(nident,(ikmpc,&idof1,nmpc,&id1));
+/*	      FORTRAN(nident,(ikmpc,&idof1,nmpc,&id1));
 	      if((id1>0)&&(ikmpc[id1-1]==idof1)) mpc1=1;
 	      FORTRAN(nident,(ikmpc,&idof2,nmpc,&id2));
-	      if((id2>0)&&(ikmpc[id2-1]==idof2)) mpc2=1;
+	      if((id2>0)&&(ikmpc[id2-1]==idof2)) mpc2=1;*/
+		if(idof1!=2*(idof1/2)) mpc1=1;
+		if(idof2!=2*(idof2/2)) mpc2=1;
 	    }
 	    if((mpc1==1)&&(mpc2==1)){
-	      id1=ilmpc[id1-1];
-	      id2=ilmpc[id2-1];
+//	      id1=ilmpc[id1-1];
+//	      id2=ilmpc[id2-1];
+	      id1=(-idof1+1)/2;
+	      id2=(-idof2+1)/2;
 	      if(id1==id2){
 		
 		/* MPC id1 / MPC id1 */
@@ -372,7 +416,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 		  index2=index1;
 		  while(1){
 		      idof2=nactdof[mt*(nodempc[3*index2-3]-1)+nodempc[3*index2-2]];
-		    if((idof1!=0)&&(idof2!=0)){
+		    if((idof1>0)&&(idof2>0)){
 		      insert(ipointer,&mast1,&next,&idof1,&idof2,&ifree,&nzs_);}
 		    index2=nodempc[3*index2-1];
 		    if(index2==0) break;
@@ -400,7 +444,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 		  }
 		  while(1){
 		      idof2=nactdof[mt*(nodempc[3*index2-3]-1)+nodempc[3*index2-2]];
-		    if((idof1!=0)&&(idof2!=0)){
+		    if((idof1>0)&&(idof2>0)){
 		      insert(ipointer,&mast1,&next,&idof1,&idof2,&ifree,&nzs_);}
 		    index2=nodempc[3*index2-1];
 		    if(index2==0) break;
@@ -478,35 +522,39 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	  
 	  /* check whether one of the DOF belongs to a SPC or MPC */
 	  
-	  if((jdof1!=0)&&(jdof2!=0)){
+	  if((jdof1>0)&&(jdof2>0)){
 	    insert(ipointer,&mast1,&next,&jdof1,&jdof2,&ifree,&nzs_);
 	  }
-	  else if((jdof1!=0)||(jdof2!=0)){
+	  else if((jdof1>0)||(jdof2>0)){
 	    
 	    /* idof1: genuine DOF
 	       idof2: nominal DOF of the SPC/MPC */
 	    
-	    if(jdof1==0){
+	    if(jdof1<=0){
 	      idof1=jdof2;
-	      idof2=8*node1-8;}
+//	      idof2=8*node1-8;}
+	      idof2=jdof1;}
 	    else{
 	      idof1=jdof1;
-	      idof2=8*node2-8;}
+//	      idof2=8*node2-8;}
+	      idof2=jdof2;}
 	    
 	    if(*nmpc>0){
 	      
-	      FORTRAN(nident,(ikmpc,&idof2,nmpc,&id));
-	      if((id>0)&&(ikmpc[id-1]==idof2)){
+//	      FORTRAN(nident,(ikmpc,&idof2,nmpc,&id));
+//	      if((id>0)&&(ikmpc[id-1]==idof2)){
+	      if(idof2!=2*(idof2/2)){
 		
 		/* regular DOF / MPC */
 		
-		id=ilmpc[id-1];
+//		id=ilmpc[id-1];
+		id=(-idof2+1)/2;
 		ist=ipompc[id-1];
 		index=nodempc[3*ist-1];
 		if(index==0) continue;
 		while(1){
 		    idof2=nactdof[mt*(nodempc[3*index-3]-1)+nodempc[3*index-2]];
-		  if(idof2!=0){
+		  if(idof2>0){
 		    insert(ipointer,&mast1,&next,&idof1,&idof2,&ifree,&nzs_);
 		  }
 		  index=nodempc[3*index-1];
@@ -516,31 +564,40 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	      }
 	    }
 
+            /* regular DOF/SPC */
+
             /* boundary stiffness coefficients (for frequency and
                modal dynamic calculations */
 
 	    if((*nmethod==2)||((*nmethod==4)&&(*iperturb<=1))||((*nmethod>=5)&&(*nmethod<=7))){
-		FORTRAN(nident,(ikboun,&idof2,nboun,&id));
-		icolumn=neq[1]+ilboun[id-1];
+//		FORTRAN(nident,(ikboun,&idof2,nboun,&id));
+//		icolumn=neq[1]+ilboun[id-1];
+		icolumn=neq[1]-idof2/2;
 		insertfreq(ipointer,&mast1,&next,&idof1,&icolumn,&ifree,&nzs_);
 	    }
 
 	  }
 	  
 	  else{
-	    idof1=8*node1-8;
-	    idof2=8*node2-8;
+//	    idof1=8*node1-8;
+//	    idof2=8*node2-8;
+	    idof1=jdof1;
+	    idof2=jdof2;
 	    mpc1=0;
 	    mpc2=0;
 	    if(*nmpc>0){
-	      FORTRAN(nident,(ikmpc,&idof1,nmpc,&id1));
+/*	      FORTRAN(nident,(ikmpc,&idof1,nmpc,&id1));
 	      if((id1>0)&&(ikmpc[id1-1]==idof1)) mpc1=1;
 	      FORTRAN(nident,(ikmpc,&idof2,nmpc,&id2));
-	      if((id2>0)&&(ikmpc[id2-1]==idof2)) mpc2=1;
+	      if((id2>0)&&(ikmpc[id2-1]==idof2)) mpc2=1;*/
+		if(idof1!=2*(idof1/2)) mpc1=1;
+		if(idof2!=2*(idof2/2)) mpc2=1;
 	    }
 	    if((mpc1==1)&&(mpc2==1)){
-	      id1=ilmpc[id1-1];
-	      id2=ilmpc[id2-1];
+//	      id1=ilmpc[id1-1];
+//	      id2=ilmpc[id2-1];
+	      id1=(-idof1+1)/2;
+	      id2=(-idof2+1)/2;
 	      if(id1==id2){
 		
 		/* MPC id1 / MPC id1 */
@@ -553,7 +610,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 		  index2=index1;
 		  while(1){
 		      idof2=nactdof[mt*(nodempc[3*index2-3]-1)+nodempc[3*index2-2]];
-		    if((idof1!=0)&&(idof2!=0)){
+		    if((idof1>0)&&(idof2>0)){
 		      insert(ipointer,&mast1,&next,&idof1,&idof2,&ifree,&nzs_);}
 		    index2=nodempc[3*index2-1];
 		    if(index2==0) break;
@@ -581,7 +638,7 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 		  }
 		  while(1){
 		      idof2=nactdof[mt*(nodempc[3*index2-3]-1)+nodempc[3*index2-2]];
-		    if((idof1!=0)&&(idof2!=0)){
+		    if((idof1>0)&&(idof2>0)){
 		      insert(ipointer,&mast1,&next,&idof1,&idof2,&ifree,&nzs_);}
 		    index2=nodempc[3*index2-1];
 		    if(index2==0) break;
