@@ -25,7 +25,8 @@
      &  qfx,ikmpc,ilmpc,istep,iinc,springarea,
      &  calcul_fn,calcul_qa,nal,nea,neb,ithermal,nelemload,nload,
      &  nmethod,reltime,sideload,xload,xloadold,pslavsurf,
-     &  pmastsurf,mortar,clearini,plicon,nplicon,ielprop,prop)
+     &  pmastsurf,mortar,clearini,plicon,nplicon,ielprop,prop,
+     &  iponoel,inoel)
 !
 !     calculates the heat flux and the material tangent at the integration
 !     points and the internal concentrated flux at the nodes
@@ -44,7 +45,8 @@
      &  nal,nmpc,kode,imat,mint3d,iorien,istiff,ncmat_,nstate_,
      &  nplkcon(0:ntmat_,*),npmat_,calcul_fn,calcul_qa,nea,neb,
      &  nelemload(2,*),nload,ithermal(2),nmethod,nopered,iloc,
-     &  jfaces,node,nplicon(0:ntmat_,*),null,ielprop(*)
+     &  jfaces,node,nplicon(0:ntmat_,*),null,ielprop(*),
+     &  iponoel(*),inoel(2,*)
 !
       real*8 co(3,*),v(0:mi(2),*),shp(4,26),reltime,
      &  xl(3,26),vl(0:mi(2),26),elcon(0:ncmat_,ntmat_,*),
@@ -239,8 +241,10 @@ c            if(lakon(i)(7:7).eq.'C') konl(nope+1)=kon(indexe+nope+1)
 !
                   call advecforc(nope,vl,ithermal,xl,nelemload,
      &                 i,nload,lakon,xload,istep,time,ttime,
-     &                 dtime,sideload,vold,mi,
-     &                 xloadold,reltime,nmethod,tnl,iinc)
+     &                 dtime,sideload,vold,mi,xloadold,reltime,nmethod,
+     &                 tnl,iinc,iponoel,inoel,ielprop,prop,ielmat,shcon,
+     &                 nshcon,rhcon,nrhcon,ntmat_,ipkon,kon,cocon,
+     &                 ncocon)
                endif
 !
             elseif(lakonl(1:2).eq.'D ') then
