@@ -38,6 +38,10 @@
       real*8 xi,et,ze,xsj,omg,omh,omr,opg,oph,opr,
      &  tpgphpr,tmgphpr,tmgmhpr,tpgmhpr,tpgphmr,tmgphmr,tmgmhmr,tpgmhmr,
      &  omgopg,omhoph,omropr,omgmopg,omhmoph,omrmopr
+!
+      intent(in) xi,et,ze,xl,iflag
+!
+      intent(out) shp,xsj
 !
 !     shape functions and their glocal derivatives
 !
