@@ -35,6 +35,10 @@
       real*8 shp(4,20),xs(3,3),xsi(3,3),xl(3,20),sh(3)
 !
       real*8 xi,et,ze,xsj,omg,omh,omr,opg,oph,opr
+!
+      intent(in) xi,et,ze,xl,iflag
+!
+      intent(out) shp,xsj
 !
 !     shape functions and their glocal derivatives
 !
