@@ -32,7 +32,7 @@
      &  iperturb(*),nmethod,mi(*),ne0,nstate_,nasym
 !
       real*8 xl(3,10),elas(21),ratio(9),pproj(3),val,shp2(7,9),
-     &  al(3),s(100,100),voldl(0:mi(2),10),pl(3,10),xn(3),dm,
+     &  al(3),s(60,60),voldl(0:mi(2),10),pl(3,10),xn(3),dm,
      &  c1,c2,c3,c4,alpha,beta,elcon(0:ncmat_,ntmat_,*),xm(3),
      &  xmu(3,3,10),dxmu(3,10),dval(3,10),fpu(3,3,10),xi,et,
      &  xs2(3,7),t1l,elconloc(21),plconloc(802),xk,fk,
@@ -74,6 +74,12 @@
             dd=dsqrt((pl(1,2)-pl(1,1))**2
      &           +(pl(2,2)-pl(2,1))**2
      &           +(pl(3,2)-pl(3,1))**2)
+            if(dd.le.0.d0) then
+               write(*,*) '*ERROR in springstiff_n2f: spring connects'
+               write(*,*) '       two nodes at the same location:'
+               write(*,*) '       spring length is zero'
+               call exit(201)
+            endif
             do i=1,3
                xn(i)=(pl(i,2)-pl(i,1))/dd
             enddo
