@@ -23,7 +23,7 @@
 !
       implicit none
 !
-      logical multistage,tied
+      logical multistage,tied,fluidperiodic,fluidcyclic
 !
       character*1 inpc(*)
       character*81 tieset(3,*)
@@ -36,6 +36,8 @@
 !
       multistage=.false.
       tied=.true.
+      fluidperiodic=.false.
+      fluidcyclic=.false.
 !
       if(istep.gt.0) then
          write(*,*) '*ERROR in ties: *TIE should'
@@ -68,6 +70,12 @@
          elseif(textpart(i)(1:10).eq.'MULTISTAGE') then
             multistage=.true.
             tied=.false.
+         elseif(textpart(i)(1:13).eq.'FLUIDPERIODIC') then
+            fluidperiodic=.true.
+            tied=.false.
+         elseif(textpart(i)(1:11).eq.'FLUIDCYCLIC') then
+            fluidcyclic=.true.
+            tied=.false.
          else
             write(*,*) 
      &        '*WARNING in ties: parameter not recognized:'
@@ -92,10 +100,14 @@
          call exit(201)
       endif
 !      
-      if ( multistage ) then
+      if(multistage) then
          tieset(1,ntie)(81:81)='M'
       elseif(tied) then
          tieset(1,ntie)(81:81)='T'
+      elseif(fluidperiodic) then
+         tieset(1,ntie)(81:81)='P'
+      elseif(fluidcyclic) then
+         tieset(1,ntie)(81:81)='Z'
       endif
 !
       if(tied) then
@@ -124,6 +136,19 @@
          tieset(3,ntie)(81:81)=' '
          ipos=index(tieset(3,ntie),' ')
          tieset(3,ntie)(ipos:ipos)='S'
+      elseif((fluidperiodic).or.(fluidcyclic)) then
+!
+!        slave and master surface must be facial
+!
+         tieset(2,ntie)(1:80)=textpart(1)(1:80)
+         tieset(2,ntie)(81:81)=' '
+         ipos=index(tieset(2,ntie),' ')
+         tieset(2,ntie)(ipos:ipos)='T'
+!     
+         tieset(3,ntie)(1:80)=textpart(2)(1:80)
+         tieset(3,ntie)(81:81)=' '
+         ipos=index(tieset(3,ntie),' ')
+         tieset(3,ntie)(ipos:ipos)='T'
       else
 !
 !        cyclic symmetry tie
