@@ -31,7 +31,7 @@
          iel=ielfa(1,i)
          iel=nactdohinv(iel)
          write(*,*) 'writevfa ',iel,ielfa(4,i),
-     &      vfa(1,i),vfa(2,i),vfa(3,i)
+     &      vfa(0,i),vfa(1,i),vfa(2,i),vfa(3,i)
       enddo
 !     
       return
