@@ -1110,6 +1110,12 @@ c         endif
                zeta=lam20/64*(V2V0*a0a2)**2-zetlin+1d0
                zeta=zeta*(W0W2)**2
             endif
+            if(zeta.lt.0) then
+               write(*,*) '*WARNING in zeta_calc: in Element',nelem,
+     &               'TYPE= ',lakon(nelem)(2:5)
+               write(*,*) '         Zeta value negative is set to 0.01'
+               zeta=0.01d0
+            endif
             return
 !     
          elseif((lakon(nelem)(2:8).eq.'REBRJI1').or.
@@ -1176,6 +1182,12 @@ c         endif
                   zeta=zeta*(W0W2)**2
                endif
             endif
+            if(zeta.lt.0) then
+               write(*,*) '*WARNING in zeta_calc: in Element',nelem,
+     &               'TYPE= ',lakon(nelem)(2:5)
+               write(*,*) '         Zeta value negative is set to 0.01'
+               zeta=0.01d0
+            endif
             return
 !     
          elseif((lakon(nelem)(2:8).eq.'REBRJI2').or.
@@ -1274,6 +1286,12 @@ c         endif
                   endif
                endif
             endif
+            if(zeta.lt.0) then
+               write(*,*) '*WARNING in zeta_calc: in Element',nelem,
+     &               'TYPE= ',lakon(nelem)(2:5)
+               write(*,*) '         Zeta value negative is set to 0.01'
+               zeta=0.01d0
+            endif
             return
 !
          elseif((lakon(nelem)(2:7).eq.'REBRSG').or.
@@ -1390,8 +1408,15 @@ c         endif
             endif
             return
          endif
+         if(zeta.lt.0) then
+            write(*,*) '*WARNING in zeta_calc: in Element',nelem,
+     &           'TYPE= ',lakon(nelem)(2:5)
+            write(*,*) '         Zeta value negative is set to 0.01'
+            zeta=0.01d0
+         endif
       endif
-!     
+!   
+      return
       end
       
       
